@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2012-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -100,8 +100,6 @@ require 'version.pl';
 require 'fileDir.pl';
 require 'dateTools.pl';
 
-
-
 my $tmpdir = '/tmp';              # default value
 $tmpdir = $ENV{'TMPDIR'} if defined $ENV{'TMPDIR'};
 
@@ -121,6 +119,7 @@ linkToDirs.pl - hard links files in directories with others
 		       [--printDepth] [--dontLinkSymlinks]
 		      [--ignoreErrors] [--saveRAM] [-T tmpdir]
 		      [--createSparseFiles [--blockSize]]
+		      [--maxHardLinks]
 		      sourceDir ...
 
 =head1 DESCRIPTION
@@ -202,21 +201,24 @@ linked always in targetDir.
     path(s) to directories which have to be linked to other backups
     use this parameter multiple times for multiple directories
 
+=item B<--maxHardLinks>
+
+    maximum number of hard links to use
+    zero (default) means limit depends on file system used only
+
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012-2013 by Heinz-Josef Claes (see README).
+Copyright (c) 2012-2020 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'yes',
@@ -258,8 +260,11 @@ my $CheckPar =
 				Option->new('-name' => 'tmpdir',
 					    '-cl_option' => '-T',
 					    '-cl_alias' => '--tmpdir',
-					    '-cf_key' => 'tmpDir',
-					    '-default' => $tmpdir)
+					    '-default' => $tmpdir),
+				Option->new('-name' => 'maxHardLinks',
+					    '-cl_option' => '--maxHardLinks',
+					    '-default' => 0,
+					    '-pattern' => '\A\d+\Z')
 				]);
 
 $CheckPar->check('-argv' => \@ARGV,
@@ -278,8 +283,15 @@ my (@sourceDir) = $CheckPar->getListPar();
 my $saveRAM = $CheckPar->getOptWithoutPar('saveRAM');
 my $createSparseFiles = $CheckPar->getOptWithoutPar('createSparseFiles');
 my $blockSize = $CheckPar->getOptWithPar('blockSize');
+my $maxHardLinks = $CheckPar->getOptWithPar('maxHardLinks');
 $tmpdir = $CheckPar->getOptWithPar('tmpdir');
 
+if (not $targetDir or not @sourceDir)
+{
+    print "$Help";
+    exit 0;
+}
+
 my $prLog;
 my ($prLogKind) = ['A:BEGIN',
 		   'Z:END',
@@ -289,7 +301,8 @@ my ($prLogKind) = ['A:BEGIN',
 		   'E:ERROR',
 		   'S:STATISTIC',
 		   'P:PROGRESS'];
-$prLog = printLog->new('-kind' => $prLogKind);
+$prLog = printLog->new('-kind' => $prLogKind,
+		       '-tmpdir' => $tmpdir);
 
 # check progressReport settings
 my $progressDeltaTime = 0;
@@ -645,7 +658,27 @@ foreach my $d (@sourceDir)
 		my $foundFile = $indexDir->replaceIndex($iFile);
 
 #print "\tlink (1) $foundFile => $fnew\n";
-		unless ($linkSymlinks and link $foundFile => $fnew)
+
+
+	    my $hl = -1;
+	    if ($maxHardLinks > 0)
+	    {
+		$hl = (stat($foundFile))[3];
+		if ($t eq 'l')   # symlink
+		{
+		    $hl = (lstat($foundFile))[3];
+		}
+		else
+		{
+		    $hl = (stat($foundFile))[3];
+		}
+#print "$foundFile: $hl hardlinks ($maxHardLinks)\n";
+	    }
+	    if ($hl < $maxHardLinks and not
+		($linkSymlinks and link $foundFile, $fnew))
+#		unless ($linkSymlinks and link $foundFile, $fnew)
+
+
 		{
 #print "\t\t!!!copy $f =>$fnew\n";
 		    my ($fbase, $fname, $index) = $indexDir->newFile($fnew);
@@ -722,7 +755,26 @@ foreach my $d (@sourceDir)
 		    my $foundFile = $indexDir->replaceIndex($iFile);
 
 #print "\tlink (2) $foundFile => $fnew\n";
-		    unless ($linkSymlinks and link $foundFile => $fnew)
+
+
+	    my $hl = -1;
+	    if ($maxHardLinks > 0)
+	    {
+		if ($t eq 'l')   # symlink
+		{
+		    $hl = (lstat($foundFile))[3];
+		}
+		else
+		{
+		    $hl = (stat($foundFile))[3];
+		}
+#print "$foundFile: $hl hardlinks ($maxHardLinks)\n";
+	    }
+	    if ($hl < $maxHardLinks and not
+		($linkSymlinks and link $foundFile, $fnew))
+#		unless ($linkSymlinks and link $foundFile, $fnew)
+
+
 		    {
 #print "\t\t!!!copy $f =>$fnew\n";
 			my ($fbase, $fname, $index) = $indexDir->newFile($fnew);
@@ -796,13 +848,25 @@ foreach my $d (@sourceDir)
 		    $stat->incrCopy();
 		}
 	    }
-	    chown $uid, $gid, $fnew;
-	    chmod $mode, $fnew;
-	    utime $atime, $mtime, $fnew;
+	    if ($t eq 'l')      # symbolic link
+	    {
+		my $chown =
+		    forkProc->new('-exec' => 'chown',
+				  '-param' => ['-h', "$uid:$gid", $fnew],
+				  '-outRandom' => "$tmpdir/chown-",
+				  '-prLog' => $prLog);
+		$chown->wait();
+	    }
+	    else
+	    {
+		chown $uid, $gid, $fnew;
+		chmod $mode, $fnew;
+		utime $atime, $mtime, $fnew;
+	    }
 	}
 	else   # all file types except 'f' and 'd'
 	{
-	    &::copyDir($f, $fnew, '/tmp/stbuLink-', $prLog, $ignoreErrors);
+	    &::copyDir($f, $fnew, "$tmpdir/stbuLink-", $prLog, $ignoreErrors);
 	    $stat->incrCopy();
 	}
     }
