@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2000-2013)
+#   Copyright (C) Heinz-Josef Claes (2000-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -88,6 +88,7 @@ require "checkParam2.pl";
 require "tail.pl";
 require "prLog.pl";
 require 'version.pl';
+require 'fileDir.pl';
 
 
 my (%colors) = ('red' => 1,
@@ -144,7 +145,7 @@ multiTail.pl - Read multiple log files. The log files can be written round.
 
     maximal len of file written round (default = 1e6)
 
-=item B<-n>, B<--noOldFiles>
+=item B<-n>, B<--noOfOldFiles>
 
     number of old files to store
 
@@ -165,7 +166,7 @@ multiTail.pl - Read multiple log files. The log files can be written round.
 =item B<-s>, B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOldFiles])
+    old (with [-noOfOldFiles])
 
 =item B<-c>, B<--compressWith>
 
@@ -194,16 +195,14 @@ multiTail.pl - Read multiple log files. The log files can be written round.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2013 by Heinz-Josef Claes (see README)
+Copyright (c) 2001-2020 by Heinz-Josef Claes (see README)
 Published under the GNU General Public License or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $CheckPar = CheckParam->new('-allowLists' => 'yes',
 			       '-list' => [
@@ -234,9 +233,9 @@ my $CheckPar = CheckParam->new('-allowLists' => 'yes',
 					       '-cl_option' => '-m',
 					       '-cl_alias' => '--maxFilelen',
 					       '-default' => 1e6),
-				   Option->new('-name' => 'noOldFiles',
+				   Option->new('-name' => 'noOfOldFiles',
 					       '-cl_option' => '-n',
-					       '-cl_alias' => '--noOldFiles',
+					       '-cl_alias' => '--noOfOldFiles',
 					       '-param' => 'yes',
 					       '-only_if' =>
 				'[pit] and not ( [saveLogs] or [compressWith])'),
@@ -256,13 +255,13 @@ my $CheckPar = CheckParam->new('-allowLists' => 'yes',
 					       '-cl_option' => '-s',
 					       '-cl_alias' => '--saveLogs',
 					       '-only_if' =>
-					       '[out] and not [noOldFiles]'),
+					       '[out] and not [noOfOldFiles]'),
 				   Option->new('-name' => 'compressWith',
 					       '-cl_option' => '-c',
 					       '-cl_alias' => '--compressWith',
 					       '-param' => 'yes',
 					       '-only_if' =>
-					       '[out] and not [noOldFiles]'),
+					       '[out] and not [noOfOldFiles]'),
 				   Option->new('-name' => 'color',
 					       '-cl_option' => '-C',
 					       '-cl_alias' => '--color',
@@ -285,7 +284,7 @@ my $print = $CheckPar->getOptWithoutPar('print');
 my $withTime = ($CheckPar->getOptWithoutPar('withTime')) ? 'yes' : 'no';
 my $out = $CheckPar->getOptWithPar('out');
 my $maxFilelen = $CheckPar->getOptWithPar('maxFilelen');
-my $noOldFiles = $CheckPar->getOptWithPar('noOldFiles');
+my $noOfOldFiles = $CheckPar->getOptWithPar('noOfOldFiles');
 my $withPID = $CheckPar->getOptWithoutPar('withPID') ? 'yes' : 'no';
 my $hostname = $CheckPar->getOptWithoutPar('withHostname') ? `hostname -f` : '';
 chomp $hostname;
@@ -353,7 +352,7 @@ my (@fileout) = ('-file' => $out) if ($out);
 my $prLog = printLog->new(@fileout,
 			  '-withTime' => $withTime,
 			  '-maxFilelen' => $maxFilelen,
-			  '-noOfOldFiles' => $noOldFiles,
+			  '-noOfOldFiles' => $noOfOldFiles,
 			  '-saveLogs' => $saveLogs,
 			  '-compressWith' => $compressWith,
 			  '-withPID' => $withPID,
