@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2012-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -95,7 +95,6 @@ require 'checkObjPar.pl';
 require 'prLog.pl';
 require 'version.pl';
 require 'fileDir.pl';
-require 'forkProc.pl';
 require 'storeBackupLib.pl';
 
 my $checkSumFile = '.md5CheckSums';
@@ -182,7 +181,7 @@ compared to the backup, it:
 =item B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOldFiles])
+    old (with [-noOfOldFiles])
 
 =item B<--compressWith>
 
@@ -193,16 +192,14 @@ compared to the backup, it:
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012-2013 by Heinz-Josef Claes (see README).
+Copyright (c) 2012-2020 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'no',
@@ -344,7 +341,7 @@ $SIG{TERM} = \&cleanup;
 
 
 $prLog->print('-kind' => 'A',
-	      '-str' => ["comparing <$singleBackupDir> to <$sourceDir>"]);
+	      '-str' => ["comparing <$singleBackupDir> with <$sourceDir>"]);
 $prLog->print('-kind' => 'V',
 	      '-str' => ["storeBackupCheckSource.pl, $main::STOREBACKUPVERSION"]);
 
