@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2002-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2002-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -84,6 +84,7 @@ my ($req, $prog) = &libPath($0);
 push @INC, "$req";
 
 require 'version.pl';
+require 'fileDir.pl';
 
 my $md5CheckSums = '.md5CheckSums';
 
@@ -111,16 +112,14 @@ bzip2 -d < ...<storeBackupDir>/date_time/.md5CheckSums.bz2 | head -1
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2013 by Heinz-Josef Claes (see README)
+Copyright (c) 2002-2020 by Heinz-Josef Claes (see README)
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 die $Help if (@ARGV != 1);
 
