@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2003-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2003-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -98,7 +98,9 @@ require 'dateTools.pl';
 require 'fileDir.pl';
 require 'humanRead.pl';
 
-my $lockFile = '/tmp/storeBackup.lock';   # default value
+my $lockFile = ($ENV{'USER'} eq 'root') ?     # default value
+		'/var/lock/storeBackup.lock' :
+		$ENV{'HOME'} . '/storeBackup.lock';
 my $keepAll = '30d';
 my $keepDuplicate = '7d';
 my $checkSumFile = '.md5CheckSums';
@@ -156,6 +158,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
     and is not designed to separate storeBackup.pl and
     storeBackupUpdateBackup.pl or any other storeBackup
     process in a separate PID space
+    Default lock file for root is in /var/lock, for others in \$HOME
 
 =item B<--doNotDelete>
 
@@ -255,7 +258,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
     Alternative deletion scheme. If you use this option, all other
     keep options are ignored. Preserves backups depending
     on their *relative* age. Example:
-    -R '1d 7d 2m 3m'
+    -R '1d 7d 61d 92d'
         will (try to) ensure that there is always
 	- One backup between 1 day and 7 days old
 	- One backup between 5 days and 2 months old
@@ -288,7 +291,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
 =item B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOldFiles])
+    old (with [-noOfOldFiles])
 
 =item B<--compressWith>
 
@@ -299,16 +302,14 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2013 by Heinz-Josef Claes (see README).
+Copyright (c) 2003-2020 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $startDate = dateTools->new();
 
@@ -397,6 +398,7 @@ my $CheckPar =
 					    '-pattern' => '\A\d+\Z'),
                                 Option->new('-name' => 'keepRelative',
 					    '-cl_option' => '--keepRelative',
+					    '-cl_alias' => '-R',
 					    '-cf_key' => 'keepRelative',
 					    '-quoteEval' => 'yes',
 					    '-param' => 'yes'),
@@ -571,44 +573,7 @@ my $allLinks = lateLinks->new('-dirs' => [$targetDir],
 #
 # lock file berprfen
 #
-if ($lockFile)
-{
-    if (-f $lockFile)
-    {
-	open(FILE, "< $lockFile") or
-	    $prLog->print('-kind' => 'E',
-			  '-str' => ["cannot read lock file <$lockFile>"],
-			  '-exit' => 1);
-	my $pid = <FILE>;
-	chop $pid;
-	close(FILE);
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["strange format in lock file <$lockFile>, " .
-				 "line is <$pid>"],
-		      '-exit' => 1)
-	    unless ($pid =~ /\A\d+\Z/o);
-	if (kill(0, $pid) == 1)   # alte Instanz luft noch
-	{
-	    $prLog->print('-kind' => 'E',
-			  '-str' => ["cannot start, old instance with pid " .
-				     "<$pid> is already running"],
-			  '-exit' => 1);
-	}
-	else
-	{
-	    $prLog->print('-kind' => 'I',
-			  '-str' => ["removing old lock file of process <$pid>"]
-			  );
-	}
-    }
-
-    open(FILE, "> $lockFile") or
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot create lock file <$lockFile>"],
-		      '-exit' => 1);
-    print FILE "$$\n";
-    close(FILE);
-}
+::checkLockFile($lockFile, $prLog);
 
 my $statDelOldBackupDirs =
     statisticDeleteOldBackupDirs->new('-prLog' => $prLog);
