@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2004-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2004-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -93,9 +93,13 @@ require 'prLog.pl';
 require 'forkProc.pl';
 require 'dateTools.pl';
 require 'version.pl';
+require 'fileDir.pl';
 
 $main::exit = 0;                               # exit status
 
+my $tmpdir = '/tmp';              # default value
+$tmpdir = $ENV{'TMPDIR'} if defined $ENV{'TMPDIR'};
+
 =head1 NAME
 
 Mounts file systems (defined in /etc/fstab) and starts storeBackup
@@ -113,13 +117,16 @@ or
 or
         storeBackupMount.pl -f configFile
 or
-	storeBackupMount.pl [-s servers] [-l logFile] [-d]
+	storeBackupMount.pl [-s servers] [-d] [-l logFile
+	       [--suppressTime] [-m maxFilelen]
+	       [[-n noOfOldFiles] | [--saveLogs]]
+	       [--compressWith compressprog]]
 	    [--storeBackup storeBackup-Params]
 	    [--storeBackupUpdateBackup storeBackupUpdateBackup-Params]
 	    [--storeBackupCheckBackup storeBackupCheckBackup-Params]
 	    [--storeBackupCheckSource storeBackupCheckSource-Params]
 	    [--storeBackupDel storeBackupDel-Params]
-	    [--printAndStop] [-k killTime] [mountPoints...]
+	    [--printAndStop] [-k killTime] [-T tmpdir] [mountPoints...]
 
 =head1 DESCRIPTION
 
@@ -159,14 +166,38 @@ This script does the following:
     name(s) or ip address(es) of the nfs server(s)
     This option can be repeated multiple times
 
+=item B<--debug>, B<-d>
+
+    generate some debug messages
+
 =item B<--logFile>, B<-l>
 
     logFile for this process.
     default is STDOUT.
 
-=item B<--debug>, B<-d>
+=item B<--suppressTime>
 
-    generate some debug messages
+    suppress output of time in logfile
+
+=item B<--maxFilelen>, B<-m>
+
+    maximal length of log file, default = 1e6
+
+=item B<--noOfOldFiles>, B<-n>
+
+    number of old log files, default = 5
+
+=item B<--saveLogs>
+
+    save log files with date and time instead of deleting the
+    old (with [-noOfOldFiles])
+
+=item B<--compressWith>
+
+    compress saved log files (e.g. with 'gzip -9')
+    default is 'bzip2'
+    This parameter is parsed like a line in the configuration
+    file and normally has to be quoted.
 
 =item B<--storeBackup>
 
@@ -219,6 +250,10 @@ This script does the following:
     the time range has to be specified in format 'dhms', e.g.
     10d4h means 10 days and 4 hours
 
+=item B<--tmpdir>, B<-T>
+
+    directory for temporary files, default is </tmp>
+
 =item F<mountPoints>
 
     List of mount points needed to perform the backup.
@@ -253,14 +288,12 @@ This script does the following:
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004-2013 by Heinz-Josef Claes (see README).
+Copyright (c) 2004-2020 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
 my $templateConfigFile = <<EOC;
 # configuration file for storeBackupMount.pl, version $main::STOREBACKUPVERSION
@@ -304,12 +337,30 @@ my $templateConfigFile = <<EOC;
 # only root is allowed to use this feature!
 ;mountPoints=
 
+# generate some debug messages
+;debug=
+
 # logFile for this process.
 # default is STDOUT.
 ;logFile=
 
-# generate some debug messages
-;debug=
+# output in logfile without time: 'yes' or 'no'
+# default = no
+;suppressTime=
+
+# maximal length of log file, default = 1e6
+;maxFilelen=
+
+# number of old log files, default = 5
+;noOfOldFiles=
+
+# save log files with date and time instead of deleting the
+# old (with [-noOfOldFiles]): 'yes' or 'no', default = 'no'
+;saveLogs=
+
+# compress saved log files (e.g. with 'gzip -9')
+# default is 'bzip2'
+;compressWith=
 
 # run storeBackup.pl
 # use this parameter to define the options for storeBackup.pl, eg.:
@@ -349,12 +400,14 @@ my $templateConfigFile = <<EOC;
 # 10d4h means 10 days and 4 hours
 ;killTime=
 
+# directory for temporary file, default is /tmp
+;tmpDir=
 EOC
     ;
 
 
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my (@progs) = ('storeBackup', 'storeBackupUpdateBackup', 'storeBackupCheckBackup',
 	       'storeBackupCheckSource', 'storeBackupDel');
@@ -391,16 +444,45 @@ my $CheckPar =
 					    '-cf_key' => 'servers',
 					    '-multiple' => 'yes',
 					    '-param' => 'yes'),
-				Option->new('-name' => 'logFile',
-					    '-cl_option' => '-l',
-					    '-cl_alias' => '--logFile',
-					    '-cf_key' => 'logFile',
-					    '-param' => 'yes'),
 				Option->new('-name' => 'debug',
 					    '-cl_option' => '-d',
 					    '-cl_alias' => '--debug',
 					    '-cf_key' => 'debug',
 					    '-cf_noOptSet' => ['yes', 'no']),
+				Option->new('-name' => 'logFile',
+					    '-cl_option' => '-l',
+					    '-cl_alias' => '--logFile',
+					    '-cf_key' => 'logFile',
+					    '-param' => 'yes'),
+				Option->new('-name' => 'suppressTime',
+					    '-cl_option' => '--suppressTime',
+					    '-cf_key' => 'suppressTime',
+					    '-cf_noOptSet' => ['yes', 'no']),
+				Option->new('-name' => 'maxFilelen',
+					    '-cl_option' => '-m',
+					    '-cl_alias' => '--maxFilelen',
+					    '-cf_key' => 'maxFilelen',
+					    '-default' => 1e6,
+					    '-pattern' => '\A[e\d]+\Z',
+					    '-only_if' => "[logFile]"),
+				Option->new('-name' => 'noOfOldFiles',
+					    '-cl_option' => '-n',
+					    '-cl_alias' => '--noOfOldFiles',
+					    '-cf_key' => 'noOfOldFiles',
+					    '-default' => '5',
+					    '-pattern' => '\A\d+\Z',
+					    '-only_if' =>"[logFile]"),
+                                Option->new('-name' => 'saveLogs',
+					    '-cl_option' => '--saveLogs',
+					    '-cf_key' => 'saveLogs',
+					    '-only_if' => "[logFile]",
+					    '-cf_noOptSet' => ['yes', 'no']),
+                                Option->new('-name' => 'compressWith',
+					    '-cl_option' => '--compressWith',
+					    '-cf_key' => 'compressWith',
+					    '-default' => 'bzip2',
+					    '-quoteEval' => 'yes',
+					    '-only_if' =>"[logFile]"),
 				@progOpts,
 				Option->new('-name' => 'printAndStop',
 					    '-cl_option' => '-p',
@@ -410,6 +492,11 @@ my $CheckPar =
 					    '-cl_alias' => '--killTime',
 					    '-cf_key' => 'killTime',
 					    '-default' => '365d'),
+				Option->new('-name' => 'tmpdir',
+					    '-cl_option' => '-T',
+					    '-cl_alias' => '--tmpdir',
+					    '-cf_key' => 'tmpDir',
+					    '-default' => $tmpdir),
                                 Option->new('-name' => 'mountPoints',
 					    '-cf_key' => 'mountPoints',
 					    '-multiple' => 'yes'),
@@ -428,9 +515,7 @@ EOH
     ;
 # '
 
-my $FullHelp = join('', grep(!/^\s*$/, `pod2text $0`));
-$FullHelp = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $FullHelp = &::getPod2Text($0);
 
 # Auswertung der Parameter
 my $help = $CheckPar->getOptWithoutPar('help');
@@ -441,14 +526,21 @@ my (%argForProgs);
 my $configFile = $CheckPar->getOptWithPar('configFile');
 my $generateConfigFile = $CheckPar->getOptWithPar('generate');
 my $servers = $CheckPar->getOptWithPar('servers');
-my $logFile = $CheckPar->getOptWithPar('logFile');
 my $debug = $CheckPar->getOptWithoutPar('debug');
+my $logFile = $CheckPar->getOptWithPar('logFile');
+my $withTime = not $CheckPar->getOptWithoutPar('suppressTime');
+$withTime = $withTime ? 'yes' : 'no';
+my $maxFilelen = $CheckPar->getOptWithPar('maxFilelen');
+my $noOfOldFiles = $CheckPar->getOptWithPar('noOfOldFiles');
+my $saveLogs = $CheckPar->getOptWithoutPar('saveLogs');
+my $compressWith = $CheckPar->getOptWithPar('compressWith');
 foreach my $a (@progs)
 {
     $argForProgs{$a} = $CheckPar->getOptWithPar($a);
 }
 my $printAndStop = $CheckPar->getOptWithoutPar('printAndStop');
 my $kt = $CheckPar->getOptWithPar('killTime');
+$tmpdir = $CheckPar->getOptWithPar('tmpdir');
 my (@mountPoints) = $CheckPar->getListPar();
 my $orderOfExecution = $CheckPar->getOptWithPar('orderOfExecution');
 
@@ -510,8 +602,8 @@ die "$Help"
     unless @progsToStart;
 
 
-my $pLog = printLog->new();
-my $fifo = ::uniqFileName('/tmp/prLog-');
+my $pLog = printLog->new('-tmpdir' => $tmpdir);
+my $fifo = ::uniqFileName("$tmpdir/prLog-");
 POSIX::mkfifo($fifo, 0600) or
     $pLog->print('-kind' => 'E',
 		 '-str' => ["cannot mknod <$fifo> for storeBackupMount.pl"],
@@ -520,7 +612,12 @@ POSIX::mkfifo($fifo, 0600) or
 my (@logArgs) = ();
 if ($logFile)
 {
-    (@logArgs) = ('--out' => $logFile);
+#    (@logArgs) = ('--out' => $logFile);
+    (@logArgs) = ('--out' => $logFile,
+		  '--maxFilelen' => $maxFilelen,
+		  '--noOfOldFiles' => $noOfOldFiles,
+		  '--compressWith' => $compressWith);
+    push @logArgs, '--saveLogs'	if $saveLogs;
 }
 my $logD = forkProc->new('-exec' => "$req/stbuLog.pl",
 			 '-param' => ['--readFile' => $fifo,
@@ -535,14 +632,19 @@ my ($prLogKind) = ['A:BEGIN',
 		   'D:DEBUG',
 		   'W:WARNING',
 		   'E:ERROR'];
+
 if ($logFile)
 {
     $prLog = printLog->new('-file' => $fifo,
-			   '-kind' => $prLogKind);
+			   '-kind' => $prLogKind,
+			   '-withTime' => $withTime,
+			   '-tmpdir' => $tmpdir);
 }
 else
 {
-    $prLog = printLog->new('-kind' => $prLogKind);
+    $prLog = printLog->new('-kind' => $prLogKind,
+			   '-withTime' => $withTime,
+			   '-tmpdir' => $tmpdir);
 }
 
 
@@ -654,7 +756,7 @@ foreach $m (@mountPoints)
 		  '-str' => ["trying to mount @opt $m"]);
     my $fp = forkProc->new('-exec' => 'mount',
 			   '-param' => [@opt, $m],
-			   '-outRandom' => '/tmp/doStoreBackup-forkMount-',
+			   '-outRandom' => "$tmpdir/doStoreBackup-forkMount-",
 			   '-prLog' => $prLog);
 
     # wait for a maximum of 10 seconds
@@ -734,7 +836,7 @@ foreach my $p (@progsToStart)
     my $stbu = forkProc->new('-exec' => "$prog",
 			     '-param' => [@$params,
 					  '--writeToNamedPipe' => $fifo],
-			     '-outRandom' => '/tmp/doStoreBackup-stbu-',
+			     '-outRandom' => "$tmpdir/doStoreBackup-stbu-",
 			     '-prLog' => $prLog);
 
     if ($killTime)
@@ -747,7 +849,8 @@ foreach my $p (@progsToStart)
 	    {
 		$ready = 1;
 		my $status;
-		if ($status = $stbu->get('-what' => 'status'))
+#		if ($status = $stbu->get('-what' => 'status'))
+		if ($main::exit |= $status = $stbu->get('-what' => 'status'))
 		{
 		    $prLog->print('-kind' => 'E',
 				  '-str' =>
@@ -815,7 +918,7 @@ sub umount
 	my $um = forkProc->new('-exec' => 'umount',
 			       '-param' => [$m],
 			       '-outRandom' =>
-			       '/tmp/doStoreBackup-forkMount-',
+			       "$tmpdir/doStoreBackup-forkMount-",
 			       '-prLog' => $prLog);
 
 	# wait for a maximum of 60 seconds
