@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2002-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2002-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -23,7 +23,7 @@ $main::STOREBACKUPVERSION = undef;
 
 
 use strict;
-use DB_File;           # Berkeley DB version 1
+use Fcntl;
 use Digest::MD5 qw(md5_hex);
 
 
@@ -179,16 +179,14 @@ storeBackupRecover.pl - recovers files saved with storeBackup.pl.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2013 by Heinz-Josef Claes (see README).
+Copyright (c) 2002-2020 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'no',
@@ -256,7 +254,8 @@ my $createSparseFiles = $CheckPar->getOptWithoutPar('createSparseFiles');
 
 
 my $prLog = printLog->new('-kind' => ['I:INFO', 'W:WARNING', 'E:ERROR',
-				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION']);
+				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION'],
+			  '-tmpdir' => $tmpdir);
 $prLog->fork($req);
 
 $prLog->print('-kind' => 'E',
@@ -268,6 +267,15 @@ $prLog->print('-kind' => 'V',
 	      '-str' => ["storeBackupRecover.pl, $main::STOREBACKUPVERSION"])
     if $verbose;
 
+eval "use DB_File";
+if ($@)
+{
+    $prLog->print('-kind' => 'I',
+		  '-str' => ["please install DB_File from " .
+			     "CPAN for better performance"])
+	if $verbose;
+}
+
 my $rt = $restoreTree;
 my $restoreTree = &absolutePath($restoreTree);
 $restoreTree = $1 if $restoreTree =~ /(.*)\/$/;  # remove trailing '/'
@@ -358,7 +366,8 @@ unless ($flat)
 
 my $rcsf = readCheckSumFile->new('-checkSumFile' =>
 				 "$backupRoot/$checkSumFile",
-				 '-prLog' => $prLog);
+				 '-prLog' => $prLog,
+				 '-tmpdir' => $tmpdir);
 
 my $fork = parallelFork->new('-maxParallel' => $noRestoreParallel,
 			     '-prLog' => $prLog);
@@ -496,7 +505,7 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	{
 	    unless ($noHardLinks)
 	    {
-		if (exists($DBMHardLink{$devInode}))   # muss nur gelinkt werden
+		if (defined($DBMHardLink{$devInode}))   # muss nur gelinkt werden
 		{
 		    if (link $DBMHardLink{$devInode}, $targetFile)
 		    {
@@ -550,7 +559,7 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 		$archiveTypes =~ /p/)
 	    {
 		&::extractFileFromArchive($filename, $targetDir, $backupRoot,
-		    $specialTypeArchiver, $prLog);
+		    $specialTypeArchiver, $prLog, $tmpdir);
 		$prLog->print('-kind' => 'I',
 			      '-str' =>
 	     ["$specialTypeArchiver $backupRoot/$filename -> $targetFile"])
@@ -605,7 +614,7 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 
 	    unless ($noHardLinks) # Hard Link berprfen
 	    {
-		if (exists($DBMHardLink{$devInode}))   # muss nur gelinkt werden
+		if (defined($DBMHardLink{$devInode}))   # muss nur gelinkt werden
 		{
 		    $hasToBeLinked{$targetFile} = [$devInode, $uid, $gid, $mode,
 						   $atime, $mtime];
@@ -635,10 +644,12 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 		    $noCharDevs++ if $md5sum eq 'chardev';
 
 		    if ($specialTypeArchiver and
-			$archiveTypes =~ /[Sbc]/)
+			length($md5sum) < 32)
+#			$archiveTypes =~ /[Sbc]/)
 		    {
 			&::extractFileFromArchive($filename, $targetDir, $backupRoot,
-						  $specialTypeArchiver, $prLog);
+						  $specialTypeArchiver, $prLog,
+						  $tmpdir);
 
 			$prLog->print('-kind' => 'I',
 				      '-str' =>
@@ -849,7 +860,7 @@ sub setHardLinks
     foreach $f (keys %$hasToBeLinked)
     {
 	my ($di, $uid, $gid, $mode, $atime, $mtime) = @{$$hasToBeLinked{$f}};
-	if (exists($$DBMHardLink{$di}) and $$DBMHardLink{$di} ne '.')
+	if (defined($$DBMHardLink{$di}) and $$DBMHardLink{$di} ne '.')
 	{
 	    my $oldF = $$DBMHardLink{$di};
 	    if (-e $f)
@@ -901,7 +912,7 @@ sub uncompressCatBlock
 	pipeFromFork->new('-exec' => 'bzip2',
 			  '-param' => ['-d'],
 			  '-stdin' => "$fromDir/.md5BlockCheckSums.bz2",
-			  '-outRandom' => '/tmp/stbuPipeFrom11-',
+			  '-outRandom' => "$tmpdir/stbuPipeFrom11-",
 			  '-prLog' => $prLog);
     my $l;
     while ($l = $fileIn->read())
@@ -978,7 +989,7 @@ sub uncompressCatBlock
 		    pipeFromFork->new('-exec' => $uncompr,
 				      '-param' => \@uncomprPar,
 				      '-stdin' => "$backupRoot/$entry",
-				      '-outRandom' => '/tmp/stbuPipeFrom11-',
+				      '-outRandom' => "$tmpdir/stbuPipeFrom11-",
 				      '-prLog' => $prLog);
 		while ($fileIn->sysread(\$buffer, 10*1024**2))
 		{
