@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2012-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -96,6 +96,10 @@ require 'forkProc.pl';
 require 'dateTools.pl';
 require 'version.pl';
 require 'tail.pl';
+require 'fileDir.pl';
+
+my $tmpdir = '/tmp';              # default value
+$tmpdir = $ENV{'TMPDIR'} if defined $ENV{'TMPDIR'};
 
 
 my $commentMasterBackup =
@@ -121,7 +125,7 @@ storeBackupReplicationWizard.pl - creates configuration files for replication
 =head1 SYNOPSIS
 
     storeBackupReplicationWizard.pl [-m masterBackupDir]
-          [-c backupCopyDir] [-d deltaCacheDir] [-S series]
+          [-c backupCopyDir] [-d deltaCacheDir] [-S series] [-T tmpdir]
 
 =head1 DESCRIPTION
 
@@ -154,22 +158,24 @@ create them
     series to be replicated
     use this parameter multiple times for multiple series
 
+=item B<--tmpdir>, B<-T>
+
+    directory for temporary files, default is </tmp>
+
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012-2013 by Heinz-Josef Claes (see README).
+Copyright (c) 2012-2020 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
 my $binPath = &::absolutePath("$req/../bin");
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $CheckPar =
     CheckParam->new('-list' =>
@@ -189,7 +195,11 @@ my $CheckPar =
 				 '-cl_option' => '-S',
 				 '-cl_alias' => '--series',
 				 '-param' => 'yes',
-				 '-multiple' => 'yes')
+				 '-multiple' => 'yes'),
+		     Option->new('-name' => 'tmpdir',
+				 '-cl_option' => '-T',
+				 '-cl_alias' => '--tmpdir',
+				 '-default' => $tmpdir)
 		    ]
     );
 
@@ -215,6 +225,7 @@ my $backupCopyDir = $CheckPar->getOptWithPar('backupCopyDir');
 my $deltaCacheDir = $CheckPar->getOptWithPar('deltaCacheDir');
 my $series = $CheckPar->getOptWithPar('series');
 (@$series) = sort (@$series) if $series;
+$tmpdir = $CheckPar->getOptWithPar('tmpdir');
 
 #
 # check if parameters are set
@@ -440,7 +451,7 @@ $prLog->print('-kind' => 'I',
 #
 # generate configuration files
 #
-my $tmpDir = &::uniqFileName('/tmp/stbuRW-');
+my $tmpDir = &::uniqFileName("$tmpdir/stbuRW-");
 mkdir $tmpDir, 0700 or
     $prLog->print('-kind' => 'E',
 		  '-str' => ["cannot create temporary directory <$tmpDir>"],
