@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2012-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -119,13 +119,13 @@ based on configuration file:
 
     storeBackupSetupIsolatedMode.pl -f configFile -t targetDir
     				[-S series] [-g newConfigFile]
-				[-e explicitBackup] [-v]
+				[-e explicitBackup] [-v] [-F]
 
 
 no configuration file:
 
     storeBackupSetupIsolatedMode.pl -b backupDir -t targetDir
-    				[-S series] [-e explicitBackup] [-v]
+    				[-S series] [-e explicitBackup] [-v] [-F]
 
 =head1 OPTIONS
 
@@ -173,20 +173,23 @@ no configuration file:
 
     generate verbose messages
 
+=item B<--force>, B<-F>
+
+    force usage of last backup (with lateLinks), even it if has
+    not been completed with storeBackupUpdateBackup.pl
+
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012-2013 by Heinz-Josef Claes (see README).
+Copyright (c) 2012-2020 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'no',
@@ -222,7 +225,10 @@ my $CheckPar =
 					    '-only_if' => '[configFile]'),
 				Option->new('-name' => 'verbose',
 					    '-cl_option' => '-v',
-					    '-cl_alias' => '--verbose')
+					    '-cl_alias' => '--verbose'),
+				Option->new('-name' => 'force',
+					    '-cl_option' => '-F',
+					    '-cl_alias' => '--force')
 				]);
 
 $CheckPar->check('-argv' => \@ARGV,
@@ -237,6 +243,7 @@ my $configFile = $CheckPar->getOptWithPar('configFile');
 my $generateConfigFile = $CheckPar->getOptWithPar('generate');
 my $targetDir = $CheckPar->getOptWithPar('targetDir');
 my $verbose = $CheckPar->getOptWithoutPar('verbose');
+my $force = $CheckPar->getOptWithoutPar('force');
 
 
 my $prLog;
@@ -397,7 +404,10 @@ else
     my $e;
     foreach $e (@entries)
     {
-	if (-e "$backupDir/$series/$e/.md5CheckSums.notfinished")
+#	if (-e "$backupDir/$series/$e/.md5CheckSums.notfinished")
+	unless (&::checkIfBackupWasFinished('-backupDir' => "$backupDir/$series/$e",
+					    '-prLog' => $prLog,
+			    '-count' => 50))
 	{
 	    $prLog->print('-kind' => 'W',
 			  '-str' => ["<$backupDir/$series/$e> not finished"]);
@@ -415,11 +425,13 @@ else
 
     $prLog->print('-kind' => 'E',
 		  '-str' =>
-       ["last backupDir <$backupDir> needs to run storeBackupUpdateBackup.pl, " .
-	"please do so and repeat running this program" .
-	"or use option --explicitBackup"],
+       ["last backupDir <$backupDir> needs",
+	"to run storeBackupUpdateBackup.pl, ",
+	"please do so and repeat running this program",
+	"or use option --explicitBackup or option --force"],
 		  '-exit' => 1)
-	if -e "$lastBackupDir/.storeBackupLinks/linkFile.bz2";
+	if -e "$lastBackupDir/.storeBackupLinks/linkFile.bz2"
+	and not $force;
 
     $prLog->print('-kind' => 'I',
 		  '-str' =>
@@ -613,7 +625,8 @@ $prLog->print('-kind' => 'I',
 	      '-str' => ["created directory <$targetBackupDir>"])
     if $verbose;
 
-&::copyStbuSpecialFiles($lastBackupDir, $targetBackupDir, $prLog, $verbose);
+&::copyStbuSpecialFiles($lastBackupDir, $targetBackupDir, $prLog, $verbose,
+			'/tmp');
 
 $prLog->print('-kind' => 'I',
 	      '-str' =>
