@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2008-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2008-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -99,7 +99,9 @@ require 'dateTools.pl';
 require 'fileDir.pl';
 require 'humanRead.pl';
 
-my $lockFile = '/tmp/storeBackup.lock';   # default value
+my $lockFile = ($ENV{'USER'} eq 'root') ?     # default value
+		'/var/lock/storeBackup.lock' :
+		$ENV{'HOME'} . '/storeBackup.lock';
 my $checkSumFile = '.md5CheckSums';
 my $blockCheckSumFile = '.md5BlockCheckSums';
 my $baseTreeConf = "storeBackupBaseTree.conf";
@@ -118,7 +120,8 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 	      [--print] [--verbose] [--debug] [--lockFile] [--noCompress]
 	      [--progressReport number] [--checkOnly] [--copyBackupOnly]
 	      [--dontCopyBackup] [-A archiveDurationDeltaCache]
-	      [--dontDelInDeltaCache]
+	      [--dontDelInDeltaCache] [--createNewSeries]
+	      [--noWarningDiffSeriesInBackupCopy] [--maxHardLinks]
 	      [--logFile
 	       [--plusLogStdout] [--suppressTime] [-m maxFilelen]
 	       [[-n noOfOldFiles] | [--saveLogs]]
@@ -177,6 +180,7 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
     and is not designed to separate storeBackup.pl and
     storeBackupUpdateBackup.pl or any other storeBackup
     process in a separate PID space
+    Default lock file for root is in /var/lock, for others in \$HOME
 
 =item B<--noCompress>
 
@@ -211,6 +215,13 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 =item B<--dontDelInDeltaCache>
     do not delete any backup in deltaCache
 
+=item B<--createNewSeries> B<-C>
+
+    Automatically create new series in deltaCache and the
+    replication directory / directories. This is especially useful
+    if you use wildcards to specify series name which should be
+    added 'on the fly'
+
 =item B<--progressReport>
 
     print progress report:
@@ -225,6 +236,17 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 
 =back
 
+=item B<--noWarningDiffSeriesInBackupCopy>, B<-N>
+
+    do not write a warning if there is a different set of series
+    inside the backup copy (replication directory) than in the
+    actual deltaCache
+
+=item B<--maxHardLinks>
+
+    maximum number of hard links to use
+    zero (default) means limit depends on file system used only
+
 =item B<--logFile>, B<-l>
 
     logFile, Default: stdout
@@ -249,7 +271,7 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 =item B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOldFiles])
+    old (with [-noOfOldFiles])
 
 =item B<--compressWith>
 
@@ -270,16 +292,14 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2013 by Heinz-Josef Claes.
+Copyright (c) 2008-2020 by Heinz-Josef Claes.
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $startDate = dateTools->new();
 my $CheckPar =
@@ -323,6 +343,10 @@ my $CheckPar =
                                 Option->new('-name' => 'dontDelInDeltaCache',
 					    '-cl_option' => '--dontDelInDeltaCache',
 					    '-only_if' => 'not [interactive]'),
+				Option->new('-name' => 'createNewSeries',
+					    '-cl_option' => '-C',
+					    '-only_if' => 'not [interactive]',
+					    '-cl_alias' => '--createNewSeries'),
 				Option->new('-name' => 'progressReport',
 					    '-cl_option' => '--progressReport',
 					    '-default' => 0,
@@ -335,6 +359,14 @@ my $CheckPar =
 					    '-cl_option' => '--debug',
 					    '-cl_alias' => '-d',
 					    '-only_if' => 'not [interactive]'),
+				Option->new('-name' => 'noWarningDiffSeriesInBackupCopy',
+					    '-cl_option' => '-N',
+					    '-only_if' => 'not [interactive]',
+					    '-cl_alias' => '--noWarningDiffSeriesInBackupCopy'),
+				Option->new('-name' => 'maxHardLinks',
+					    '-cl_option' => '--maxHardLinks',
+					    '-default' => 0,
+					    '-pattern' => '\A\d+\Z'),
 				Option->new('-name' => 'logFile',
 					    '-cl_option' => '-l',
 					    '-cl_alias' => '--logFile',
@@ -402,7 +434,11 @@ my $copyBackupOnly = $CheckPar->getOptWithoutPar('copyBackupOnly');
 my $dontCopyBackup = $CheckPar->getOptWithoutPar('dontCopyBackup');
 $archiveDurationDeltaCache = $CheckPar->getOptWithPar('archiveDurationDeltaCache');
 my $dontDelInDeltaCache = $CheckPar->getOptWithoutPar('dontDelInDeltaCache');
+my $createNewSeries = $CheckPar->getOptWithoutPar('createNewSeries');
 my $progressReport = $CheckPar->getOptWithPar('progressReport');
+my $noWarningDiffSeriesInBackupCopy =
+    $CheckPar->getOptWithoutPar('noWarningDiffSeriesInBackupCopy');
+my $maxHardLinks = $CheckPar->getOptWithPar('maxHardLinks');
 my $logFile = $CheckPar->getOptWithPar('logFile');
 my $plusLogStdout = $CheckPar->getOptWithoutPar('plusLogStdout');
 my $withTime = not $CheckPar->getOptWithoutPar('suppressTime');
@@ -647,12 +683,22 @@ exit 1
 
 my (%seriesToCopy);   # $seriesToCopy{series}{backupCopyName}
 my $deltaCache = undef;
+my $backupType = 'none';
 if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 {
 # read storeBackupBaseTree.conf in $backupDir
-    my ($backupTreeName, $backupType, $seriesToDistribute);
+    my ($backupTreeName, $seriesToDistribute);
     ($backupTreeName, $backupType, $seriesToDistribute, $deltaCache) =
-	&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf", $prLog);
+	&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf",
+				     &::absolutePath($backupDir), $prLog);
+
+#print "-1----------------=======------------\n";
+    # replace wildcards in replicated backup
+    my (@readSeries) = &::evalExceptionList_PlusMinus($seriesToDistribute,
+					    &::absolutePath($backupDir),
+				      "$backupTreeName series", 'series', 1,
+					    undef, 1, $prLog);
+#print "-1.1------readSeries=@readSeries\n";
 
 #print "backupTreeName = <$backupTreeName>\n";
 #print "backupType = <$backupType>\n";
@@ -675,11 +721,63 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 
     if ($backupType eq 'copy')
     {
-	$autorepairError = 0;
+#print "-2----------------=======------------\n";
+	# build hash with list of series in replication directory
+	my (%readSeries);
+#print "readSeries=<@readSeries>\n";
+	foreach my $r (@readSeries)
+	{
+#print "$r\n";
+	    $readSeries{$r} = 1;
+	}
+
 	# read deltaCache.conf in $deltaCache
 	my $cscFile = "$deltaCache/$deltaCacheConf";
+	my (@bc) = &::readDeltaCacheConf($cscFile, $deltaCache, 1, $prLog);
 
-	my (@bc) = &::readDeltaCacheConf($cscFile, $prLog);
+#print "-2.5----------------=======------------\n";
+	# generate list with existing series in Delta Cache
+	my (@listSeriesExistInDelta) = ();
+	foreach my $bc (@bc)
+	{
+#print "===> $bc[0][0] --------- $backupTreeName\n";
+	    if ($bc[0][0] eq $backupTreeName)
+	    {
+		(@listSeriesExistInDelta) = (@$bc[1..@$bc-1]);
+	    }
+#print "-3----------+Delta Cache Series++++++@listSeriesExistInDelta++\n";
+	}
+	# generate missing series directories in replication directory
+	# This has to be done 'on the fly' also when using wildcards in series names
+	my $createSeries = 0;
+	foreach my $d (@listSeriesExistInDelta)
+	{
+#print "3.5 -- <$d> -- ", (defined $readSeries{$d}), "\n";
+	    if ($createNewSeries and not defined $readSeries{$d})
+	    {
+#print "3.6-- <$backupDir/$d>\n";
+		exit 1
+		    unless &::makeDirPath("$backupDir/$d", $prLog);
+		$createSeries = 1;
+	    }
+	}
+#print "-4----------------=======------------\n";
+#print "-4.1------seriesToDistribute=@$seriesToDistribute\n";
+	if ($createSeries)
+	{
+	    # replace wildcards in replicated backup
+	    (@readSeries) = &::evalExceptionList_PlusMinus($seriesToDistribute,
+						    &::absolutePath($backupDir),
+						    "$backupTreeName series", 'series',
+						    1, undef, 1, $prLog);
+	}
+	$seriesToDistribute =\@readSeries;
+#print "-4.2------seriesToDistribute=@$seriesToDistribute\n";
+
+	$autorepairError = 0;
+#	# read deltaCache.conf in $deltaCache
+#	my $cscFile = "$deltaCache/$deltaCacheConf";
+#	my (@bc) = &::readDeltaCacheConf($cscFile, $deltaCache, 1, $prLog);
 
 	# check consistency of backupCopy and deltaCache configuration
 	my $foundBackupTreeNameFlag = 0;
@@ -710,18 +808,19 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 		}
 		foreach $s (@$seriesToDistribute)
 		{
+#print "---removing series <$s>\n";
 		    if (exists $s{$s})
 		    {
 			delete $s{$s};
 		    }
 		    else
 		    {
-			$prLog->print('-kind' => 'E',
+			$prLog->print('-kind' => 'W',
 				      '-str' =>
 				      ["$cscFile: series <$s> is missing in <" .
 				       $$bc[0] . ">, defined in " .
-				       "$backupDir/$baseTreeConf"],
-				      '-exit' => 1);
+				       "$backupDir/$baseTreeConf"])
+			    unless $noWarningDiffSeriesInBackupCopy;
 		    }
 
 		}
@@ -730,7 +829,9 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 			      '-str' =>
 			      ["$backupDir/$baseTreeConf series <" .
 			       join('><', sort keys %s) . "> missing in <" .
-			       $$bc[0] . ">, defined in $cscFile"],
+			       $$bc[0] . ">, defined in $cscFile",
+			       "use option --createNewSeries if you want " .
+			       "missing series to be created automatically"],
 			      '-exit' => 1)
 		    if scalar keys %s;
 	    }
@@ -815,6 +916,8 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
     }
     elsif ($backupType eq 'master')
     {
+	$seriesToDistribute = \@readSeries;
+
 	my $s;
 	foreach $s (@$seriesToDistribute)
 	{
@@ -992,7 +1095,8 @@ while (((@lateLinkDirs) = $allLinks->getAllDirsWithLateLinks()) > 0)
 	$updateDirFlag = 1;
 	++$numberDirsToLinkCount;
 	::updateBackupDir($d, $noCompress, $progressReport, $prLog,
-			  $interactive, "$numberDirsToLinkCount/$numberDirsToLink");
+			  $interactive, "$numberDirsToLinkCount/$numberDirsToLink",
+			  $backupType);
 
 	if (-e "$backupDir/$baseTreeConf")
 	{
@@ -1009,7 +1113,15 @@ while (((@lateLinkDirs) = $allLinks->getAllDirsWithLateLinks()) > 0)
 #print "<$d> ==> <$aktBackupDir> <$aktSeries> <$aktBackup>\n";
 
 	    my ($backupTreeName, $backupType, $seriesToDistribute, $deltaCache) =
-		&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf", $prLog);
+		&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf",
+					     &::absolutePath($backupDir), $prLog);
+	    # replace wildcards
+	    my (@readSeries) = &::evalExceptionList_PlusMinus($seriesToDistribute,
+						    &::absolutePath($backupDir),
+					    "$backupTreeName series", 'series', 0,
+						    undef, 1, $prLog);
+	    $seriesToDistribute =\@readSeries;
+
 	    my $found = 0;
 	    foreach my $s (@$seriesToDistribute)
 	    {
@@ -1280,8 +1392,8 @@ if (-e "$backupDir/$baseTreeConf" and $deltaCache)
 	my $dirs =
 	    allStoreBackupSeries->new('-rootDir' => "$cspb/$s",
 				      '-checkSumFile' => $checkSumFile,
-				      '-prLog' => $prLog,
-				      '-absPath' => 0);
+				      '-prLog' => $prLog);
+#				      '-absPath' => 0);
 	my (@dirs) = $dirs->getAllFinishedDirs();   # oldest first
 	my $d;
 	foreach $d (@dirs)
@@ -1401,6 +1513,7 @@ sub updateBackupDir
     my $prLog = shift;
     my $interactive = shift;
     my $count = shift;
+    my $backupType = shift;
 
     #
     # read compress from .md5CheckSum.info
@@ -1419,6 +1532,8 @@ sub updateBackupDir
     my ($compr, @comprPar) = @{$rcsf->getInfoWithPar('compress')};
     my $comprPostfix = $rcsf->getInfoWithPar('postfix');
 #print "compr = <$compr>, comprPar = <@comprPar>\n";
+    my $linkToRecent = $rcsf->getInfoWithPar('linkToRecent');
+#print "linkToRecent = <$linkToRecent>\n";
 
     #
     # set links and compress
@@ -1457,6 +1572,7 @@ sub updateBackupDir
 	next if $l =~ /^#/;
 	chomp $l;
 	my ($what, $md5) = split(/\s+/, $l, 2);
+#print "what = $what\n";
 
 	if ($what eq 'dir')
 	{
@@ -1619,6 +1735,40 @@ sub updateBackupDir
 	    if (unlink $f) != 1;
     }
 
+if ($backupType eq 'copy' and $linkToRecent)
+{
+    my ($_d, $link) = &::splitFileDir($dir);
+#print "_d = <$_d>, link = <$link>\n";
+    if (-l "$_d/$linkToRecent")
+    {
+	unlink "$_d/$linkToRecent";
+
+	$prLog->print('-kind' => 'W',
+		      '-str' => ["cannot create symlink linkToRecent " .
+				 "<$linkToRecent>"])
+	    unless symlink $link, "$_d/$linkToRecent";
+	++$noSymLink;
+#print "1 symlink $link, _d/$linkToRecent\n";
+    }
+    elsif (-e "$_d/$linkToRecent")
+    {
+	$prLog->print('-kind' => 'W',
+		      '-str' => ["cannot delete <$linkToRecent> " .
+				 "(option linkToRecent): " .
+				 "is not a symbolic link " .
+				 "or no permissons"]);
+    }
+    else    # does not exist, create a new one
+    {
+	$prLog->print('-kind' => 'W',
+		      '-str' => ["cannot create symlink linkToRecent " .
+				 "<$linkToRecent>"])
+	    unless symlink $link, "$_d/$linkToRecent";
+	++$noSymLink;
+#print "2 symlink $link, _d/$linkToRecent\n";
+    }
+}
+
     my $percent = $oldSize ? $newSize / $oldSize * 100 : 0;
     $prLog->print('-kind' => 'S',
 		  '-str' => ["created $noMkdir directories",
@@ -1682,7 +1832,13 @@ sub updateBackupDir
 	    $newLink =~ s/\0/\n/og;
 	    $newLink = "$dir/$newLink";
 	    $existingFile = $md5ToFile{$md5} if exists $md5ToFile{$md5};
-	    if (link $existingFile, $newLink)
+	    my $hl = -1;
+	    if ($maxHardLinks > 0)
+	    {
+		$hl = (stat($existingFile))[3];
+print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
+	    }
+	    if ($hl < $maxHardLinks and link $existingFile, $newLink)
 	    {
 		$noHardLinks++;
 		$prLog->print('-kind' => 'S',
@@ -1733,7 +1889,13 @@ sub updateBackupDir
 	    chomp $newLink;
 	    $newLink =~ s/\0/\n/og;
 	    $newLink = "$dir/$newLink";
-	    if (link $existingFile, $newLink)
+	    my $hl = -1;
+	    if ($maxHardLinks  > 0)
+	    {
+		$hl = (lstat($existingFile))[3];
+#print "$existingFile: $hl hardlinks on symlinks ($maxHardLinks)\n";
+	    }
+	    if ($hl < $maxHardLinks and link $existingFile, $newLink)
 	    {
 		$noHardLinks++;
 		$prLog->print('-kind' => 'S',
@@ -1772,7 +1934,7 @@ sub updateBackupDir
 
 	    $noHardLinks +=
 		&::hardLinkDir($existingFile, $newLink, '\A\d.*',
-			       undef, undef, undef, $prLog);
+			       undef, undef, undef, $prLog, $maxHardLinks);
 
 	    if ($withBlockedFiles)
 	    {
@@ -1874,7 +2036,7 @@ sub updateBackupDir
 	    if (not -l $file and not -e $file)
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["cannot acces <$file>"]);
+			      '-str' => ["cannot access <$file>"]);
 		next;
 	    }
 	    $noFiles++;
@@ -1965,7 +2127,7 @@ sub updateBackupDir
 		unless (-e $file)
 		{
 		    $prLog->print('-kind' => 'E',
-				  '-str' => ["cannot acces <$file>"]);
+				  '-str' => ["cannot access <$file>"]);
 		    next;
 		}
 		chown $uid, $gid, $file;
