@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2002-2013)
+#   Copyright (C) Dr. Heinz-Josef Claes (2002-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -171,16 +171,14 @@ non-blocked in different backups. In such cases, use option B<--locateSame>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2013 by Heinz-Josef Claes (see README)
+Copyright (c) 2002-2020 by Heinz-Josef Claes (see README)
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+my $Help = &::getPod2Text($0);
 
-&printVersion(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V', '--version');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'no',
@@ -323,7 +321,7 @@ $checkSumFileRoot .= ".bz2" if (-f "$backupRoot/$checkSumFile.bz2");
 $prLog->print('-kind' => 'E',
 	      '-str' => ["no info file <$checkSumFileRoot> in <$backupRoot>"],
 	      '-exit' => 1)
-    unless(-f "$backupRoot/$checkSumFileRoot");
+    unless (-f "$backupRoot/$checkSumFileRoot");
 
 # jetzt $restoreTree relativ zu $backupRoot machen
 my $fileWithRelPath = substr($file, length($backupRoot) + 1);
