@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2000-2013)
+#   Copyright (C) Heinz-Josef Claes (2000-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -126,7 +126,7 @@ sub checkObjectParams
     {
 	my $p = $::checkObjectParams_TracePre;
 	print "${p}calling $nameOfMethod with parameters\n";
-	foreach $key (keys %$defaults)
+	foreach $key (sort keys %$defaults)
 	{
 	    my $r = $$defaults{$key};
 	    if (ref($r) eq 'ARRAY')
@@ -160,4 +160,52 @@ sub setParamsDirect      # Das Minus-Zeichen der Parameter wird entfernt
     }
 }
 
+
+#
+# prints data structure on STDOUT
+#
+$main::prDformat = 0;
+$main::prDstep = 4;
+sub printData
+{
+    my $d = shift;        # pointer to data structure
+    my $comment = shift;  # comment string printed with data structure
+    print "$comment\n" if defined $comment;
+
+    $main::prDformat += $main::prDstep;
+    my $type = ref($d);
+#    print "type = $type\n";
+    if ($type eq 'REF')
+    {
+	print ' ' x $main::prDformat, "REF:\n";
+	$main::prDformat -= $main::prDstep;
+	&::printData($$d);
+	$main::prDformat += $main::prDstep;
+    }
+    if ($type eq 'SCALAR')
+    {
+	print ' ' x $main::prDformat,
+	    (defined $$d ? $$d : '<undef>'), "\n";
+    }
+    elsif ($type eq 'ARRAY')
+    {
+	print ' ' x $main::prDformat, "ARRAY:\n";
+	foreach my $a (@$d)
+	{
+	    &::printData(\$a);
+	}
+    }
+    elsif ($type eq 'HASH')
+    {
+	print ' ' x $main::prDformat, "HASH:\n";
+	foreach my $k (sort keys %$d)
+	{
+	    my $r = $$d{$k};
+	    print ' ' x ($main::prDformat+1), $k, " => \n";
+	    &::printData(\$r);
+	}
+    }
+    $main::prDformat -= $main::prDstep;
+}
+
 1
