@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2002-2013)
+#   Copyright (C) Heinz-Josef Claes (2002-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -231,6 +231,8 @@
 use strict;
 
 require 'checkObjPar.pl';
+require 'prLog.pl';
+
 ######################################################################
 # Speicherung s"amtlicher Informationen "uber *einen* Parameter
 package Option;
@@ -312,7 +314,6 @@ sub new
 
     die "-multiple must be 'yes' or 'no' in option <", $params{'-name'}, ">"
 	unless $params{'-multiple'} =~ /\Ayes\Z|\Ano\Z/;
-
     die "-priority must be 'cl' or 'cf' in option <", $params{'-name'}, ">"
 	unless $params{'-priority'} =~ /\Acl\Z|\Acf\Z/;
 
@@ -360,7 +361,8 @@ sub new
     # Defaultwerte f"ur Parameter setzen
     my (%params) = ('-file' => undef,
 		    '-replaceEnvVar' => 'yes',
-		    '-ignoreLeadingWhiteSpace' => undef
+		    '-ignoreLeadingWhiteSpace' => undef,
+		    '-prLog' => undef
 	);
 
     &::checkObjectParams(\%params, \@_, 'ConfigFile::new',
@@ -368,8 +370,13 @@ sub new
     &::setParamsDirect($self, \%params);
     bless $self, $class;
 
-    die "replaceEnvVar must be 'yes' or 'no' in ConfigFile::new"
-	unless $self->{'replaceEnvVar'} =~ /\Ayes\Z|\Ano\Z/;
+    my $prLog = $self->{'prLog'};
+
+    unless ($self->{'replaceEnvVar'} =~ /\Ayes\Z|\Ano\Z/)
+    {
+	my $err = "replaceEnvVar must be 'yes' or 'no' in ConfigFile::new";
+	&ConfigFile::printDie($err, $prLog);
+    }
     my $ignoreLeadingWhiteSpace = $self->{'ignoreLeadingWhiteSpace'};
 
     # read config file
@@ -378,16 +385,20 @@ sub new
     if ($file =~ /\.bz2\Z/)
     {
 	open(FILE, "bzip2 -d < \'$file\' |") or
-	    die "cannot open configuration file <$file>";
+	    &ConfigFile::printDie("cannot open configuration file <$file>",
+				  $prLog);
     }
     elsif ($file =~ /\.gz\Z/)
     {
 	open(FILE, "gzip -d < \'$file\' |") or
-	    die "cannot open configuration file <$file>";
+	    &ConfigFile::printDie("cannot open configuration file <$file>",
+				  $prLog);
     }
     else
     {
-	open(FILE, $file) or die "cannot open configuration file <$file>";
+	open(FILE, $file) or
+	    &ConfigFile::printDie("cannot open configuration file <$file>",
+				  $prLog);
     }
     my (@configFile) = <FILE>;
     chomp @configFile;
@@ -427,8 +438,10 @@ sub new
 	    }
 	    else
 	    {
-		die "cannot identify line $i in file $file:\n<",
-		$configFile[$i-1], ">\n";
+		&ConfigFile::printDie(
+		     "cannot identify line $i in file $file:\n<" .
+		     $configFile[$i-1] . ">",
+		     $prLog);
 	    }
 	}
     }
@@ -440,7 +453,8 @@ sub new
 	$l = $keys{$actKey}{'line'};
 	my $v = splitQuotedLine($l, "in configuration file at line " .
 				$keys{$actKey}{'lineno'},
-				$self->{'replaceEnvVar'} eq 'no');
+				$self->{'replaceEnvVar'} eq 'no',
+				$prLog);
 	if (@$v)
 	{
 	    $keys{$actKey}{'parts'} = $v;
@@ -454,15 +468,40 @@ sub new
     return $self;
 }
 
+########################################
+sub printDie
+{
+    my $err = shift;
+    my $prLog = shift;
+
+    if (defined($prLog))
+    {
+	$prLog->print('-kind' => 'E',
+		      '-str' => [$err],
+		      '-exit' => 1);
+    }
+    else
+    {
+	die $err;
+    }
+}
+
 ########################################
 sub splitQuotedLine
 {
     my $l = shift;
     my $errorPart = shift;   # where this happens, 'in file at ...'
     my $doNotReplaceEnvVar = shift;   # 1 or undef
+    my $prLog = shift;       # pointer to object or <undef>
 
     $doNotReplaceEnvVar = 0 unless defined $doNotReplaceEnvVar;
 
+#print "splitQuotedLine: l = <$l>\n";
+#print "splitQuotedLine: errorPart = <$errorPart>\n";
+#print "splitQuotedLine: doNotReplaceEnvVar = <$doNotReplaceEnvVar>\n";
+#print "splitQuotedLine: prLog = <$prLog>\n";
+
+
     # masking of special characters
     my $dollar = "\001";  # mask for \$
     my $ob = "\002";      # open bracket: mask for \{
@@ -488,7 +527,7 @@ sub splitQuotedLine
 	if ($sQuote == -1 and $dQuote == -1)   # no quotes
 	{
 	    push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-					    $errorPart,
+					    $errorPart, $prLog,
 					    split(/\s+/, $l));
 	    $l = '';
 	}
@@ -499,7 +538,7 @@ sub splitQuotedLine
 	    if ($l =~ /\A(.*?)\'(.*?)\'(.*)\Z/)
 	    {
 		push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-						$errorPart,
+						$errorPart, $prLog,
 						split(/\s+/, $1));
 		push @l, $2;
 		$l = $3;
@@ -507,7 +546,8 @@ sub splitQuotedLine
 	    }
 	    else
 	    {
-		die "missing \' $errorPart:\n<$l>\n";
+		&ConfigFile::printDie("missing \' $errorPart:\n<$l>",
+				      $prLog);
 	    }
 	}
 	else              # double quote
@@ -516,16 +556,17 @@ sub splitQuotedLine
 	    if ($l =~ /\A(.*?)\"(.*?)\"(.*)\Z/)
 	    {
 		push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-						$errorPart,
+						$errorPart, $prLog,
 						split(/\s+/, $1));
 		push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-						$errorPart, $2);
+						$errorPart, $prLog, $2);
 #print "\t<", join('> <', @l), "> + <$l>\n";
 		$l = $3;
 	    }
 	    else
 	    {
-		die "missing \" $errorPart:\n<$l>\n";
+		&ConfigFile::printDie("missing \" $errorPart:\n<$l>",
+				      $prLog);
 	    }
 	}
     }
@@ -548,7 +589,14 @@ sub splitQuotedLine
 ########################################
 sub replaceEnvironmentVars
 {
-    my ($doNotReplaceEnvVar, $errorPart, @lines) = @_;
+    my ($doNotReplaceEnvVar, $errorPart, $prLog, @lines) = @_;
+
+#print "replaceEnvironmentVars: doNotReplaceEnvVar = <$doNotReplaceEnvVar>\n";
+#print "replaceEnvironmentVars: errorPart = <$errorPart>\n";
+#print "replaceEnvironmentVars: prLog = <$prLog>\n";
+#print "replaceEnvironmentVars: lines = <@lines>\n";
+
+    # prLog must be object or <undef>
 
     return (@lines) if $doNotReplaceEnvVar;
 
@@ -577,8 +625,9 @@ sub replaceEnvironmentVars
 		    $env = $1;
 		}
 
-		die "environment variable \$$env not set\n",
-		"please set \$$env before calling this program $errorPart"
+		&ConfigFile::printDie("environment variable \$$env not set\n" .
+		"please set \$$env before calling this program $errorPart",
+				      $prLog)
 		    unless $ENV{$env};
 
 		$l =~ s/\$\{?$env\}?/$ENV{$env}/;
@@ -613,7 +662,8 @@ sub new
 		    '-allowLists' => 'no',
 		    '-listMapping' => undef,
 		    '-replaceEnvVar' => 'yes',
-		    '-ignoreLeadingWhiteSpace' => undef);
+		    '-ignoreLeadingWhiteSpace' => undef,
+		    '-prLog' => undef);
 
     $params{'-allowLists'} = 'yes'
 	if defined $params{'-listMapping'};
@@ -623,31 +673,48 @@ sub new
     $self->{'paramList'} = \%params;    # Parameter an Objekt binden
     $self->{'listMapping'} = $params{'-listMapping'};
 
+    my $prLog = $self->{'paramList'}{'-prLog'};
     # Hash mit '-cl_option' und '-cl_alias' f"ur schnellen Zugriff auf Option
     # Hash mit '-cf_key' f"ur schnellen Zugriff auf Option
     my (%option, %key, %name, %n, $o);
     foreach $o (@{$self->{'paramList'}{'-list'}})
     {
 	my $n = $o->get('-name');
-	die "option name <$n> used twice" if exists $n{$n};
+	if (exists $n{$n})
+	{
+	    my $err = "option name <$n> used twice (1)";
+	    &ConfigFile::printDie($err, $prLog);
+	}
 	$n{$n} = 1;
 	my $opt = undef;
 	if ($opt = $o->get('-cl_option'))
 	{
-	    die "cl_option <$opt> used twice!" if exists $option{$opt};
+	    if (exists $option{$opt})
+	    {
+		my $err = "cl_option <$opt> used twice! (2)";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	    $option{$opt} = $o;
 	    my $name = $o->get('-name');
 	    $name{$n} = $o;
 	}
 	if ($opt = $o->get('-cl_alias'))
 	{
-	    die "cl_option <$opt> used twice!" if exists $option{$opt};
+	    if (exists $option{$opt})
+	    {
+		my $err = "cl_option <$opt> used twice! (3)";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	    $option{$opt} = $o;
 	    $name{$n} = $o;
 	}
 	if ($opt = $o->get('-cf_key'))
 	{
-	    die "cf_key <$opt> used twice!" if exists $key{$opt};
+	    if (exists $key{$opt})
+	    {
+		my $err = "cf_key <$opt> used twice!";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	    $key{$opt} = $o;
 	    $name{$n} = $o;
 	}
@@ -677,6 +744,8 @@ sub check
 		    '-help' => ['<noHelp>'],
 		    '-ignoreAdditionalKeys' => undef);
 
+    my $prLog = $self->{'paramList'}{'-prLog'};
+
     my $replaceEnvVar =
 	$self->{'paramList'}{'-replaceEnvVar'};
     my (%hash) = @_;    # Parameter in Hash kopieren
@@ -694,9 +763,12 @@ sub check
 	}
     }
     my ($Help) = $params{'-help'};
-    die "undefined params <", join('><', keys %hash),
-    "> in CheckParam::check\n"
-	if (keys %hash > 0);
+    if (keys %hash > 0)
+    {
+	my $err = "undefined params <" . join('><' . keys %hash) .
+	    "> in CheckParam::check";
+	&ConfigFile::printDie($err, $prLog);
+    }
 
     # Die gesetzten Optionen erst einmal auf Parameter analysieren
     my $op = $self->{'optionsPointer'};
@@ -704,8 +776,12 @@ sub check
     if (defined $self->{'paramList'}{'-configFile'})
     {
 	$configFileParam = $self->{'paramList'}{'-configFile'};
-	die "CheckParam::configFile option <$configFileParam> does not exist"
-	    unless exists $op->{$configFileParam};
+	unless (exists $op->{$configFileParam})
+	{
+	    my $err =
+		"CheckParam::configFile option <$configFileParam> does not exist";
+	    &ConfigFile::printDie($err, $prLog);
+	}
     }
 
     my ($arg, @parList, $next, $aktOpt, %optWithPar,
@@ -737,15 +813,21 @@ sub check
 	}
 	if ($arg eq '--')   # n"achster Parameter ist 'list' - Parameter
 	{
-	    die "missing list parameter after '--'"
-		if $i + 1 >= @{$params{'-argv'}};
+	    if ($i + 1 >= @{$params{'-argv'}})
+	    {
+		my $err = "missing list parameter after '--'";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	    $next = 'list';
 	    next;
 	}
 	if ($arg eq '--unset')
 	{
-	    die "missing list parameter after '--unset'"
-		if $i + 1 >= @{$params{'-argv'}};
+	    if ($i + 1 >= @{$params{'-argv'}})
+	    {
+		my $err = "missing list parameter after '--unset'";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	    $next = 'unset';
 	    next;
 	}
@@ -760,35 +842,47 @@ sub check
 	    if ($o->get('-param') eq 'yes')
 	    {
 		$optWithPar{$name}{'object'} = $o;
-		die "missing param for option <$arg>\n$Help"
-		    if (++$i >= @{$params{'-argv'}});
+		if (++$i >= @{$params{'-argv'}})
+		{
+		    my $err = "missing param for option <$arg>\n$Help";
+		    &ConfigFile::printDie($err, $prLog);
+		}
 		if ($o->get('-multiple') eq 'yes')
 		{
-		    die "Parameter $arg is used for setting the configuration" .
-			" file. It cannot be used with -multiple => yes"
-			if $arg eq $configFileParam;
+			if ($arg eq $configFileParam)
+			{
+			    my $err =
+				"Parameter $arg is used for setting the configuration" .
+				" file. It cannot be used with -multiple => yes";
+			    &ConfigFile::printDie($err, $prLog);
+			}
 		    my $l = $params{'-argv'}[$i];
 		    if ($l eq '--')
 		    {
-			die "missing param for option <$arg>\n$Help"
-			    if (++$i >= @{$params{'-argv'}});
+			if (++$i >= @{$params{'-argv'}})
+			{
+			    my $err = "missing param for option <$arg>\n$Help";
+			    &ConfigFile::printDie($err, $prLog);
+			}
 			$l = $params{'-argv'}[$i];
 			push @{$optWithPar{$name}{'value'}},
 			@{ConfigFile::splitQuotedLine($l, "at <$arg>",
-			  $replaceEnvVar eq 'no')};
+			  $replaceEnvVar eq 'no', $prLog)};
 		    }
 		    else
 		    {
 			if ($o->get('-quoteEval') eq 'yes')
 			{
-			    die "cannot use $arg multiple times\n$Help",
-				if defined $optWithPar{$name}{'value'};
-
+			    if (defined $optWithPar{$name}{'value'})
+			    {
+				my $err = "cannot use $arg multiple times\n$Help";
+				&ConfigFile::printDie($err, $prLog);
+			    }
 			    $l = $params{'-argv'}[$i];
 			    $optWithPar{$name}{'value'} = ();
 			    push @{$optWithPar{$name}{'value'}},
 			    @{ConfigFile::splitQuotedLine($l, "at <$arg>",
-			      $replaceEnvVar eq 'no')};
+			      $replaceEnvVar eq 'no', $prLog)};
 			}
 			else
 			{
@@ -800,10 +894,11 @@ sub check
 		{
 		    if (defined $optWithPar{$name}{'value'})
 		    {
-			die "parameter $arg defined multiple times with\n<",
-			$optWithPar{$name}{'value'}, "> <", $params{'-argv'}[$i],
-			">\nit is not possible to have multiple instances" .
+			my $err = "parameter $arg defined multiple times with\n<" .
+			    $optWithPar{$name}{'value'} . "> <" . $params{'-argv'}[$i] .
+			    ">\nit is not possible to have multiple instances" .
 			    " of this parameter\n$Help";
+			&ConfigFile::printDie($err, $prLog);
 		    }
 		    else
 		    {
@@ -822,7 +917,11 @@ sub check
 	}
 	else      # Listenparameter
 	{
-	    die "unknown parameter <$arg>\n$Help" if ($arg =~ /^-/);
+	    if ($arg =~ /^-/)
+	    {
+		my $err = "unknown parameter <$arg>\n$Help";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	    push @parList, $arg;
 	    next;
 	}
@@ -836,7 +935,7 @@ sub check
     if (0)
     {
 	my ($k);
-	print "Ausgabe der gefundenen Command Line Optionen\n";
+	print "(1) Ausgabe der gefundenen Command Line Optionen\n";
 	print "\tOptionen mit Parameter:\n";
 	foreach $k (sort keys %optWithPar)
 	{
@@ -878,7 +977,8 @@ sub check
 	my $cf = ConfigFile->new('-file' => $configFile,
 				 '-replaceEnvVar' => $replaceEnvVar,
 				 '-ignoreLeadingWhiteSpace' =>
-				 $self->{'paramList'}{'-ignoreLeadingWhiteSpace'}
+				 $self->{'paramList'}{'-ignoreLeadingWhiteSpace'},
+				 '-prLog' => $prLog
 	    );
 
 	my $kp_cf_file = $cf->getKeysPointer();
@@ -892,8 +992,8 @@ sub check
 		my $kp = $kp_cf_file->{$fileKey};
 #print "++++++++++++\n-1- key: <$fileKey>\n";
 #print "-2- lineno: ", $kp->{'lineno'}, "\n";
-#print "-3- parts: <",
-#join("><", @{$kp->{'parts'}}), ">\n";
+#print "-3- parts: <",              # value in config file
+#    join("><", @{$kp->{'parts'}}), ">\n";
 
 		my $k = $kp_definition->{$fileKey};
 		my $name = $k->get('-name');
@@ -902,28 +1002,34 @@ sub check
 
 #print "-5- -cf_key = ", $k->get('-cf_key'), "\n";
 #print "-5- -name = ", $name, "\n";
+#print "-5- -priority = ", $k->get('-priority'), "\n";
 #print "-5- -multiple = ", $k->get('-multiple'), "\n";
 #print "-6- -cf_noOptSet = <",
-#join("><", @{$k->get('-cf_noOptSet')}), ">\n"
-#  if defined $k->get('-cf_noOptSet');
+#    join("><", @{$k->get('-cf_noOptSet')}), ">\n"
+#    if defined $k->get('-cf_noOptSet');
 
 		if (@{$kp->{'parts'}} > 1 and $k->get('-multiple') eq 'no')
 		{
-		    die "configuration file $configFile, line ",
-		    $kp->{'lineno'},
-		    ": key <$fileKey> must have only one parameter\n$Help";
+		    my $err = "configuration file $configFile, line " .
+			$kp->{'lineno'} .
+			": key <$fileKey> must have only one parameter\n$Help";
+		    &ConfigFile::printDie($err, $prLog);
 		}
-
-		next if $k->get('-priority') eq 'cl' and
-		    $k->get('-used') eq 'yes';
-
 		$k->set('-used' => 'yes');
 
 		if ($k->get('-multiple') eq 'yes')
 		{
 		    my $val = $kp->{'parts'};
 		    $val = undef if @$val == 1 and $$val[0] eq '[[undef]]';
-		    $optWithPar{$name}{'value'} = $val;
+#print "ELSE(m) $name val=<$val>,  optWithPar = ", $optWithPar{$name}{'value'}, "\n";
+#print "\tnicht definert\n" unless defined($optWithPar{$name}{'value'});
+#print "\tdefinert\n" if defined($optWithPar{$name}{'value'});
+		    if (not defined($optWithPar{$name}{'value'}) or
+			$k->get('-priority') eq 'cf')
+		    {
+			($optWithPar{$name}{'value'}) = $val;
+		    }
+
 		}
 		else           # -muliple eq 'no'
 		{
@@ -932,11 +1038,13 @@ sub check
 			my ($yes, $no) = (@{$k->get('-cf_noOptSet')});
 			my ($val) = (@{$kp->{'parts'}});
 			$val = $no unless $val;
-			die "configuration file $configFile, line ",
-			$kp->{'lineno'},
-			": value for key <$fileKey> is <$val>, must be <$yes> or <$no>"
-			    if $val ne $yes and $val ne $no;
-
+			if ($val ne $yes and $val ne $no)
+			{
+			    my $err ="configuration file $configFile, line " .
+				$kp->{'lineno'} .
+				": value for key <$fileKey> is <$val>, must be <$yes> or <$no>";
+			    &ConfigFile::printDie($err, $prLog);
+			}
 			$optWithoutPar{$name} =
 			    ($val eq $yes) ? 1 : undef;
 		    }
@@ -944,16 +1052,26 @@ sub check
 		    {
 			my $val = $kp->{'parts'}[0];
 			$val = undef if $val eq '[[undef]]';
-			($optWithPar{$name}{'value'}) = $val;
+#print "ELSE(s) $name val=<$val>,  optWithPar = ", $optWithPar{$name}{'value'}, "\n";
+#print "\tnicht definert\n" unless defined($optWithPar{$name}{'value'});
+#print "\tdefinert\n" if defined($optWithPar{$name}{'value'});
+			if (not defined($optWithPar{$name}{'value'}) or
+			    $k->get('-priority') eq 'cf')
+			{
+			    ($optWithPar{$name}{'value'}) = $val;
+			}
 		    }
 		}
 	    }
 	    else
 	    {
-		die "configuration file $configFile, line ",
-		$kp_cf_file->{$fileKey}{'lineno'},
-		": undefined key <$fileKey>\n$Help"
-		    unless $params{'-ignoreAdditionalKeys'};
+		unless ($params{'-ignoreAdditionalKeys'})
+		{
+		    my $err = "configuration file $configFile, line " .
+			$kp_cf_file->{$fileKey}{'lineno'} .
+			": undefined key <$fileKey>\n$Help";
+		    &ConfigFile::printDie($err, $prLog);
+		}
 	    }
 	}
 
@@ -962,7 +1080,7 @@ sub check
     if (0)
     {
 	my ($k);
-	print "\tOptionen aus Command Line mit Parameter:\n";
+	print "\t(2) Optionen aus Config File + Command Line mit Parameter:\n";
 	foreach $k (sort keys %optWithPar)
 	{
 	    if (ref($optWithPar{$k}{'value'}) eq 'ARRAY')
@@ -998,17 +1116,23 @@ sub check
     }
 
     # Überprüfen, ob List-Parameter erlaubt sind
-    die "detected the following not allowed list parameters:\n\t<",
-    join('> <', @parList), ">\n$Help"
-	if (@parList > 0 and $self->{'paramList'}{'-allowLists'} eq 'no');
+    if (@parList > 0 and $self->{'paramList'}{'-allowLists'} eq 'no')
+    {
+	my $err = "detected the following not allowed list parameters:\n\t<" .
+	    join('> <', @parList) . ">\n$Help";
+	&ConfigFile::printDie($err, $prLog);
+    }
+
     # map list parameters
     my $map = $self->{'paramList'}{'-listMapping'};
     if ($map)
     {
 	my $o = $self->{'namePointer'}{$map};
-	die "-listMapping object <$map> does not exist"
-	    unless $o;
-
+	unless ($o)
+	{
+	    my $err = "-listMapping object <$map> does not exist";
+	    &ConfigFile::printDie($err, $prLog);
+	}
 	if (defined($optWithPar{$map}) and $optWithPar{$map}{'value'})
 	{
 	    (@parList) = (@{$optWithPar{$map}{'value'}})
@@ -1042,13 +1166,23 @@ sub check
 	{
 	    $o = $self->{'keysPointer'}{$u};
 	}
-	die "you tried to --unset option <$u> which is not known\n$Help"
-	    unless $o;
+	unless ($o)
+	{
+	    my $err = "you tried to --unset option <$u> which is not known\n$Help";
+	    &ConfigFile::printDie($err, $prLog);
+	}
 
-	die "cannot unset <$u>, because this option must be set\n$Help"
-	    if $o->get('-must_be') eq 'yes';
-	die "option <$u> cannot be unmasked from command line\n$Help"
-	    if $o->get('-priority') eq 'cf';
+	if ($o->get('-must_be') eq 'yes')
+	{
+	    my $err ="cannot unset <$u>, because this option must be set\n$Help";
+	    &ConfigFile::printDie($err, $prLog);
+	}
+
+	if ($o->get('-priority') eq 'cf')
+	{
+	    my $err = "option <$u> cannot be unmasked from command line\n$Help";
+	    &ConfigFile::printDie($err, $prLog);
+	}
 
 	my $name = $o->get('-name');
 
@@ -1074,13 +1208,19 @@ sub check
 
 	if ($o->get('-param') eq 'no')   # kein Parameter
 	{
-	    die "missing option <$name>\n$Help"
-		unless ($optWithoutPar{$name});
+	    unless ($optWithoutPar{$name})
+	    {
+		my $err = "missing option <$name>\n$Help";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	}
 	else # hat Parameter
 	{
-	    die "missing option with parameter <$name param>\n$Help"
-		unless ($optWithPar{$name});
+	    unless ($optWithPar{$name})
+	    {
+		my $err = "missing option with parameter <$name param>\n$Help";
+		&ConfigFile::printDie($err, $prLog);
+	    }
 	}
     }
 
@@ -1100,13 +1240,14 @@ sub check
 		{
 		    if ($o->get('-comment'))
 		    {
-			die $o->get('-comment');
+			&ConfigFile::printDie($o->get('-comment'), $prLog);
 		    }
 		    else
 		    {
-			die "<", $v,
-			"> is not a valid value for option <$k>\nallowed pattern is ",
-			"<$pat>\n$Help";
+			my $err = "<" . $v .
+			    "> is not a valid value for option <$k>\nallowed pattern is " .
+			    "<$pat>\n$Help";
+			&ConfigFile::printDie($err, $prLog);
 		    }
 		}
 	    }
@@ -1117,13 +1258,14 @@ sub check
 	    {
 		if ($o->get('-comment'))
 		{
-		    die $o->get('-comment');
+		    &ConfigFile::printDie($o->get('-comment'), $prLog);
 		}
 		else
 		{
-		    die "<", $optWithPar{$k}{'value'},
-		    "> is not a valid value for option <$k>\nallowed pattern is ",
-		    "<$pat>\n$Help";
+		    my $err = "<" . $optWithPar{$k}{'value'} .
+			"> is not a valid value for option <$k>\nallowed pattern is " .
+			"<$pat>\n$Help";
+		    &ConfigFile::printDie($err, $prLog);
 		}
 	    }
 	}
@@ -1158,13 +1300,14 @@ sub check
 	{
 	    if ($o->get('-comment'))
 	    {
-		die $o->get('-comment');
+		&ConfigFile::printDie($o->get('-comment'), $prLog);
 	    }
 	    else
 	    {
-		die "illegal combination in use of option <",
-		$o->get('-name'), ">, rule = (", $o->get('-only_if'),
-		")\n\t\t\t\t\t\t  <<$only_print>>\n$Help";
+		my $err = "illegal combination in use of option <" .
+		    $o->get('-name') . ">, rule = (" . $o->get('-only_if') .
+		    ")\n\t\t\t\t\t\t  <<$only_print>>\n$Help";
+		&ConfigFile::printDie($err, $prLog);
 	    }
 	}
     }
@@ -1190,9 +1333,12 @@ sub getOptNamesSet
 			 ['-type']);
 
     my $type = $params{'-type'};
-    die "type of CheckParam->getOptNames must be withPar or withoutPar"
-	unless $type =~ /\AwithPar\Z|\AwithoutPar\Z/;
-
+    unless ($type =~ /\AwithPar\Z|\AwithoutPar\Z/)
+    {
+	my $err = "type of CheckParam->getOptNames must be withPar or withoutPar";
+	my $prLog = $self->{'paramList'}{'-prLog'};
+	&ConfigFile::printDie($err, $prLog);
+    }
     my $opts = $self->{'Erg'}{$type};
     return sort keys %$opts;
 }
@@ -1204,7 +1350,7 @@ sub print
     my $self = shift;
 
     # Defaultwerte f"ur Parameter setzen
-    my (%params) = ('-showHidden' => 0    # 1 = show hidden
+    my (%params) = ('-showHidden' => 'no'    # 'yes' = show hidden
 	);
 
     &::checkObjectParams(\%params, \@_, 'CheckParam::print', []);
@@ -1262,11 +1408,18 @@ sub getOptWithPar
     my $self = shift;
     my $par = shift;
 
-    die "option <$par> does not exist"
-	unless defined $self->{'namePointer'}{$par};
-    die "option <$par> does not have a parameter, use getOptWithoutPar"
-	unless $self->{'namePointer'}{$par}->get('-param') eq 'yes';
+    my $prLog = $self->{'paramList'}{'-prLog'};
 
+    unless (defined $self->{'namePointer'}{$par})
+    {
+	my $err =  "option <$par> does not exist";
+	&ConfigFile::printDie($err, $prLog);
+    }
+    unless ($self->{'namePointer'}{$par}->get('-param') eq 'yes')
+    {
+	my $err = "option <$par> does not have a parameter, use getOptWithoutPar";
+	&ConfigFile::printDie($err, $prLog);
+    }
     my $r = $self->{'Erg'}{'withPar'}{$par}{'value'};
     if (ref($r) eq 'ARRAY')
     {
@@ -1281,11 +1434,18 @@ sub getOptWithoutPar
     my $self = shift;
     my $par = shift;
 
-    die "option <$par> does not exist"
-	unless defined $self->{'namePointer'}{$par};
-    die "option <$par> has a parameter, use getOptWithPar"
-	unless $self->{'namePointer'}{$par}->get('-param') eq 'no';
+    my $prLog = $self->{'paramList'}{'-prLog'};
 
+    unless (defined $self->{'namePointer'}{$par})
+    {
+	my $err = "option <$par> does not exist";
+	&ConfigFile::printDie($err, $prLog);
+    }
+    unless ($self->{'namePointer'}{$par}->get('-param') eq 'no')
+    {
+	my $err = "option <$par> has a parameter, use getOptWithPar";
+	&ConfigFile::printDie($err, $prLog);
+    }
     return $self->{'Erg'}{'withoutPar'}{$par};
 }
 
