@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2001-2013)
+#   Copyright (C) Heinz-Josef Claes (2001-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -47,10 +47,14 @@ sub copyFile
     local *TARGET;
     unless (sysopen(SOURCE, $source, O_RDONLY))
     {
+	$prLog->print('-kind' => 'E',
+		      '-str' => ["cannot open <$source> for reading"]);
 	return 0;
     }
     unless (sysopen(TARGET, $target, O_CREAT | O_WRONLY))
     {
+	$prLog->print('-kind' => 'E',
+		      '-str' => ["cannot create <$target> for writing"]);
 	return 0;
     }
     my $buffer;
@@ -542,6 +546,7 @@ sub createArchiveFromFile
     my $backupDir = shift;
     my $archiver = shift;
     my $prLog = shift;
+    my $tmpdir = shift;
 
     my $prog = $main::fileTypeArchiver{$archiver}{'prog'};
     my $opts = $main::fileTypeArchiver{$archiver}{'createOpts'}; # \@list
@@ -554,7 +559,7 @@ sub createArchiveFromFile
 				'-param' => $opts,
 				'-workingDir' => $pathToSourceFile,
 				'-stdout' => "$backupDir/$filename",
-				'-stderr' => '/tmp/stbuPipeArchive-',
+				'-stderr' => "$tmpdir/stbuPipeArchive-",
 				'-delStdout' => 'no',
 				'-prLog' => $prLog);
 	$tar->wait();
@@ -564,7 +569,8 @@ sub createArchiveFromFile
 	    if (@$out > 0);
 	$out = $tar->getSTDERR();
 	$prLog->print('-kind' => 'E',
-		      '-str' => ["STDERR of <$prog @$opts>:", @$out])
+		      '-str' => ["STDERR of <$prog @$opts>:",
+				 @$out])
 	    if (@$out > 0);
     }
     elsif ($archiver eq 'cpio')
@@ -573,7 +579,7 @@ sub createArchiveFromFile
 				   '-param' => $opts,
 				   '-workingDir' => $pathToSourceFile,
 				   '-stdout' => "$backupDir/$filename",
-				   '-stderr' => '/tmp/stbuPipeArchive-',
+				   '-stderr' => "$tmpdir/stbuPipeArchive-",
 				   '-delStdout' => 'no',
 				   '-prLog' => $prLog);
 	$cpio->print("$f\n");
@@ -600,6 +606,7 @@ sub extractFileFromArchive
     my $backupDir = shift;
     my $archiver = shift;
     my $prLog = shift;
+    my $tmpdir = shift;
 
 #print "+++extractFileFromArchive:+$filename+$restoreDir+$backupDir+$archiver+\n";
     my $prog = $main::fileTypeArchiver{$archiver}{'prog'};
@@ -613,7 +620,7 @@ sub extractFileFromArchive
 	my $tar = forkProc->new('-exec' => $prog,
 				'-param' => $opts,
 				'-workingDir' => $pathToRestoreDir,
-				'-outRandom' => '/tmp/stbuPipeArchive-',
+				'-outRandom' => "$tmpdir/stbuPipeArchive-",
 				'-prLog' => $prLog);
 	$tar->wait();
 	my $out = $tar->getSTDOUT();
@@ -632,7 +639,7 @@ sub extractFileFromArchive
 				 '-param' => $opts,
 				 '-workingDir' => $pathToRestoreDir,
 				 '-stdin' => "$backupDir/$filename",
-				 '-outRandom' => '/tmp/stbuPipeArchive-',
+				 '-outRandom' => "$tmpdir/stbuPipeArchive-",
 				 '-prLog' => $prLog);
 	$cpio->wait();
 	my $out = $cpio->getSTDOUT();
@@ -738,6 +745,41 @@ sub createSparseFile
 }
 
 
+############################################################
+# read pod2text
+sub getPod2Text
+{
+    my $file = shift;
+    my $prLog = shift;    # if not set, forkProc uses STDERR
+
+    my $p2t = forkProc->new('-exec' => 'pod2text',
+			    '-param' => [$file],
+			    '-outRandom' => "/tmp/pod2text-",
+			    '-prLog' => $prLog);
+    $p2t->wait();
+    my $out = $p2t->getSTDERR();
+    if (@$out > 0)
+    {
+	if ($prLog)
+	{
+	    $prLog->print('-kind' => 'E',
+			  '-str' => ["STDERR of <pod2text>:", @$out])
+		if (@$out > 0);
+	}
+	else
+	{
+	    print STDERR "STDERR of <pod2text>:",
+	    join("\n", @$out), "\n";
+	}
+	exit 1;
+    }
+
+    $out = $p2t->getSTDOUT();
+
+    return join("\n", grep(!/^\s*$/, @$out)) . "\n";
+}
+
+
 ############################################################
 # Objekt kann zum (wiederholten) Abfragen von Informationen
 # ber eine Datei verwendet werden.
@@ -752,7 +794,8 @@ sub new
     my ($self) = {};
 
     my (%params) = ('-filename'      => undef,
-		    '-prLog'         => undef
+		    '-prLog'         => undef,
+		    '-tmpdir'        => '/tmp'
 		    );
 
     &::checkObjectParams(\%params, \@_, 'singleFileInfo::new',
@@ -785,6 +828,7 @@ sub getInfo
 			 ['-kind']);
     my $kind = $params{'-kind'};
     my $prLog = $self->{'prLog'};
+    my $tmpdir = $self->{'tmpdir'};
 
     if ($kind eq 'md5')
     {
@@ -794,8 +838,8 @@ sub getInfo
 	}
 
 	my $f = forkProc->new('-exec' => 'md5sum',
-			      '-stdout' => "/tmp/out.$$",
-			      '-stderr' => "/tmp/err.$$",
+			      '-stdout' => "$tmpdir/out.$$",
+			      '-stderr' => "$tmpdir/err.$$",
 			      '-param' => [$self->{'filename'}],
 			      '-prLog' => $prLog);
 	$f->wait();
@@ -857,6 +901,8 @@ sub new
 		    '-followLinks'         => 0, # nicht folgen, wenn 1, dann
 		                                 # in erster Ebene folgen, mehr
 		                                 # geht bisher nicht
+		    '-stayInFileSystem'    => 0, # don't leave file system, but
+		                                 # consider --followLinks
 		    '-prLog'               => undef,
 		    '-prLogError'          => 'E',
 		    '-prLogWarn'           => 'W',
@@ -902,6 +948,19 @@ sub new
     $self->{'depths'} = \@depths;
     $self->{'printedDepth'} = -1;
 
+    my %stayInFileSystemHash;
+    $self->{'stayInFileSystemHash'} = \%stayInFileSystemHash;
+    if ($self->{'stayInFileSystem'})
+    {
+	my $dirs = $self->{'dirs'};
+	foreach my $d (@$dirs)
+	{
+	    my $device = (stat($d))[0];    # device number of filesystem
+	    $stayInFileSystemHash{$device} = $d;
+#print "(1) $device --> $d\n";
+	}
+    }
+
     bless $self, $class;
 }
 
@@ -949,6 +1008,8 @@ sub readDir
     my $except = $self->{'except'};
     my $include = $self->{'include'};
     my $includeDirs = $self->{'includeDirs'};
+    my $stayInFileSystem = $self->{'stayInFileSystem'};
+    my $stayInFileSystemHash = $self->{'stayInFileSystemHash'};
     my $ignoreReadError = $self->{'ignoreReadError'};
 
 
@@ -1030,18 +1091,26 @@ sub readDir
 	{
 	    $prLog->print('-kind' => $prLogErr,
 			  '-str' =>
-			  ["cannot opendir <$dir>, exiting",
-			   "check your source and clean your backup!"],
-			  '-exit' => $exit);
+			  ["cannot opendir <$dir>, " .
+			   "you may want to set option ignoreReadError to " .
+			   "make this message a warning"]);
+#			  '-exit' => $exit);
+	    return;
 	}
     }
 
     my $entry;
     my @notPlainFiles;
+#########!!!!!!!!
+##my $output = undef;
+##print "reading $dir\n";
     while ($entry = readdir DIR)
     {
 	next if ($entry eq '.' or $entry eq '..');
 	$entry = $dir . '/' . $entry;
+#########!!!!!!!!
+##print "$output\n" if $output;
+##$output = $entry;
 
 #	my $mode = (stat($entry))[2];
 #	if (::S_ISLNK($mode))
@@ -1050,15 +1119,24 @@ sub readDir
 	    if ($self->{'followLinks'} > $depth and
                -d "$entry/.")
 	    {
+#########!!!!!!!!
+##$output = "dir_a $output";
 		if (exists $$except{&::absolutePath($entry)})
 		{
 		    $prLog->print('-kind' => 'I',
-				  '-str' => ["ignoring directory <$entry>"])
+				  '-str' => ["ignoring directory <$entry>, " .
+				  "because of option exceptDir"])
 			if $self->{'verbose'};
 		    push @$files, $entry;
 		    push @$types, 'd';
 		    next;
 		}
+		if ($stayInFileSystem)
+		{
+		    my $device = (stat($entry))[0];
+		    $$stayInFileSystemHash{$device} = $entry;
+#print "(2) $device --> $entry\n";
+		}
 		push @$files, $entry;
 		push @$types, 'd';
 		push @$dirs, $entry;
@@ -1066,6 +1144,8 @@ sub readDir
 	    }
 	    else
 	    {
+#########!!!!!!!!
+##$output = "symlink $output";
 		push @$files, $entry;
 		push @$types, 'l';
 	    }
@@ -1085,14 +1165,34 @@ sub readDir
 	    else
 	    {
 		$prLog->print('-kind' => $prLogErr,
-			      '-str' => ["no permissions to read <$entry>"],
-			      '-exit' => 1);
+			      '-str' => ["no permissions to read <$entry>, " .
+			      "you may want to set option ignoreReadError to " .
+			      "make this message a warning"]);
+#			      '-exit' => 1);
 	    }
 	    next;
 	}
 	if (-d $entry)       # Dieses Directory mu beim Kopieren
 #	if (::S_ISDIR($mode))  # Dieses Directory mu beim Kopieren
 	{                      # z.B. mu angelegt werden!
+#########!!!!!!!!
+##$output = "dir $output";
+	    if ($stayInFileSystem)
+	    {
+		my $device = (stat($entry))[0];
+		if (not exists $$stayInFileSystemHash{$device})
+		{
+		    $prLog->print('-kind' => 'I',
+				  '-str' => ["ignoring directory <$entry>, " .
+				  "because of option stayInFileSystem"])
+			if $self->{'verbose'};
+		    push @$files, $entry;
+		    push @$types, 'd';
+#print "(3) nix $device --> $entry\n";
+		    next;
+		}
+#print "(2) $device --> $entry\n";
+	    }
 	    push @$files, $entry;
 	    push @$types, 'd';
 	    next if exists $$except{&::absolutePath($entry)};
@@ -1103,6 +1203,8 @@ sub readDir
 	if (-f $entry)
 #	if (::S_ISREG($mode))
 	{
+#########!!!!!!!!
+##$output = "file $output";
 	    push @$files, $entry;
 	    push @$types, 'f';
 	    next;
@@ -1110,6 +1212,8 @@ sub readDir
 	if (-p $entry)      # named pipe
 #	if (::S_ISFIFO($mode))      # named pipe
 	{
+#########!!!!!!!!
+##$output = "pipe $output";
 	    push @$files, $entry;
 	    push @$types, 'p';
 	    next;
@@ -1117,6 +1221,8 @@ sub readDir
 	if (-S $entry)      # socket
 #	if (::S_ISSOCK($mode))      # socket
 	{
+#########!!!!!!!!
+##$output = "socket $output";
 	    push @$files, $entry;
 	    push @$types, 'S';
 	    next;
@@ -1124,6 +1230,8 @@ sub readDir
 	if (-b $entry)      # block special file
 #	if (::S_ISBLK($mode))      # block special file
 	{
+#########!!!!!!!!
+##$output = "blockSpecial $output";
 	    push @$files, $entry;
 	    push @$types, 'b';
 	    next;
@@ -1131,6 +1239,8 @@ sub readDir
 	if (-c $entry)      # character special file
 #	if (::S_ISCHR($mode))      # character special file
 	{
+#########!!!!!!!!
+##$output = "charSpecial $output";
 	    push @$files, $entry;
 	    push @$types, 'c';
 	    next;
@@ -1139,6 +1249,9 @@ sub readDir
 		      '-str' => ["unsupported file type for <$entry>"]);
     }
 
+#########!!!!!!!!
+##print "$output\n" if $output;
+
     closedir DIR;
 }
 
