@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2001-2013)
+#   Copyright (C) Heinz-Josef Claes (2001-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -83,7 +83,7 @@ sub waitForFile
 	if ($i == 0)
 	{
 	    system "/bin/sync";
-	    return (not -e $existingFile) or (stat($existingFile))[7] == 0;
+	    return ((not -e $existingFile) or (stat($existingFile))[7] == 0);
 	}
     }
 
@@ -91,6 +91,46 @@ sub waitForFile
 }
 
 
+############################################################
+sub detachFromTerminal
+{
+    my $prLog = shift;
+    my $verbose = shift;
+    my $pidfile = shift;
+
+    return if getppid() == 1;     # ist schon ein daemon
+
+    my $i = fork();
+    exit 0 if ($i == 0);           # child process beenden
+
+    unless (defined $i or POSIX::setsid())
+    {
+	unlink $pidfile if defined $pidfile;
+	$prLog->print('-kind' => 'E',
+		      '-str' => ["cannot daemonize, exiting"],
+		      '-exit' => 1);
+    }
+
+    my $i = fork();
+    exit 0 if ($i > 0);           # parent process beenden
+
+    ## Change working directory
+    chdir "/";
+
+    ## Clear file creation mask
+    umask 0;
+
+    ## Reopen stderr, stdout, stdin to /dev/null
+    open(STDIN,  "+>/dev/null");
+    open(STDOUT, "+>&STDIN");
+    open(STDERR, "+>&STDIN");
+
+    $prLog->print('-kind' => 'I',
+		  '-str' => ["daemonizing"])
+	if $verbose;
+}
+
+
 ############################################################
 package simpleFork;
 
@@ -232,13 +272,17 @@ sub new
     my $err = $params{'-prLogError'};
     my $ex = $params{'-exitIfError'};
 
+    die "use one options of <-outRandom> or <-stdout / -stderr> at" .
+	"__FILE__, __LINE__"
+	unless defined $outRandom or ($stdout and $stderr);
+
     # zufllig Dateinamen erstellen, falls ntig
-    if ($outRandom ne undef)
+    if (defined $outRandom)
     {
 	$self->{'stdout'} = $stdout = &::uniqFileName($outRandom)
-	    if $stdout eq undef;
+	    unless defined $stdout;
 	$self->{'stderr'} = $stderr = &::uniqFileName($outRandom)
-	    if $stderr eq undef;
+	    unless defined $stderr;
     }
 
     my $child;
@@ -653,7 +697,7 @@ sub new
 		    '-delStdout'   => 'yes', # lsche Datei fr stdout
 		                             # automatisch
 
-		    '-prLog'       => undef,
+		    '-prLog'       => undef, # if not set, uses STDERR
 
 		    '-info'        => undef, # beliebige zustzliche Info
 
@@ -662,7 +706,7 @@ sub new
 		    );
 
     &::checkObjectParams(\%params, \@_, 'forkProc::new',
-			 ['-exec', '-prLog']);
+			 ['-exec']);
     &::setParamsDirect($self, \%params);
 
     my $proc = $params{'-exec'};
@@ -677,12 +721,12 @@ sub new
     my $ex = $params{'-exitIfError'};
 
     # zufllig Dateinamen erstellen, falls ntig
-    if ($outRandom ne undef)
+    if (defined $outRandom)
     {
 	$self->{'stdout'} = $stdout = &::uniqFileName($outRandom)
-	    if $stdout eq undef;
+	    unless defined $stdout;
 	$self->{'stderr'} = $stderr = &::uniqFileName($outRandom)
-	    if $stderr eq undef;
+	    unless defined $stderr;
     }
 
     # jetzt forken
@@ -693,9 +737,16 @@ sub new
 	{
 	    unless (chdir "$dir")
 	    {
-		$prLog->print('-kind' => $err,
-			      '-str' =>
-			      ["Cannot chdir to <$dir> for <$proc>"]);
+		if ($prLog)
+		{
+		    $prLog->print('-kind' => $err,
+				  '-str' =>
+				  ["Cannot chdir to <$dir> for <$proc>"]);
+		}
+		else
+		{
+		    print STDERR "Cannot chdir to <$dir> for <$proc>\n";
+		}
 		exit $ex;
 	    }
 	}
@@ -703,9 +754,16 @@ sub new
 	{
 	    unless (sysopen(STDIN, $stdin, 0))
 	    {
-		$prLog->print('-kind' => $err,
-			      '-str' =>
-			      ["Cannot read <$stdin> when starting <$proc>"]);
+		if ($prLog)
+		{
+		    $prLog->print('-kind' => $err,
+				  '-str' =>
+				  ["Cannot read <$stdin> when starting <$proc>"]);
+		}
+		else
+		{
+		    print STDERR "Cannot read <$stdin> when starting <$proc>\n";
+		}
 		exit $ex;
 	    }
 	}
@@ -713,9 +771,16 @@ sub new
 	{
 	    unless (open STDOUT, "> $stdout")
 	    {
-		$prLog->print('-kind' => $err,
-			      '-str' =>
-			      ["Cannot write <$stdout> when starting <$proc>"]);
+		if ($prLog)
+		{
+		    $prLog->print('-kind' => $err,
+				  '-str' =>
+				  ["Cannot write <$stdout> when starting <$proc>"]);
+		}
+		else
+		{
+		    print STDERR "Cannot write <$stdout> when starting <$proc>\n";
+		}
 		exit $ex;
 	    }
 	    chown 0600, $stdout;
@@ -724,9 +789,16 @@ sub new
 	{
 	    unless (open STDERR, "> $stderr")
 	    {
-		$prLog->print('-kind' => $err,
-			      '-str' =>
-			      ["Cannot dup stderr when starting $proc"]);
+		if ($prLog)
+		{
+		    $prLog->print('-kind' => $err,
+				  '-str' =>
+				  ["Cannot dup stderr when starting $proc"]);
+		}
+		else
+		{
+		    print STDERR "Cannot dup stderr when starting $proc\n";
+		}
 		exit $ex;
 	    }
 	    chown 0600, $stderr;
@@ -734,8 +806,15 @@ sub new
 
 	unless (exec $proc, @$par)
 	{
-	    $prLog->print('-kind' => $err,
-			  '-str' => ["cannot exec $proc @$par"]);
+	    if ($prLog)
+	    {
+		$prLog->print('-kind' => $err,
+			      '-str' => ["cannot exec $proc @$par"]);
+	    }
+	    else
+	    {
+		print STDERR "cannot exec $proc @$par\n";
+	    }
 	    exit $ex;
 	}
     }
@@ -850,10 +929,18 @@ sub signal
 
     my $ret = kill $params{'-value'}, $self->{'pid'};
 
-    if ($ret) {
-	$self->{'prLog'}->print(-kind => 'W',
-				-str =>
-				["signaling process " . $self->{'pid'}]);
+    if ($ret)
+    {
+	if ($self->{'prLog'})
+	{
+	    $self->{'prLog'}->print(-kind => 'W',
+				    -str =>
+				    ["signaling process " . $self->{'pid'}]);
+	}
+	else
+	{
+	    print STDERR "signaling process " . $self->{'pid'} . "\n";
+	}
 	$self->delSTDOUT();
     }
     return $ret;
@@ -1190,7 +1277,7 @@ sub new
 		    '-noOfWaitSteps' => 100,
 		    '-firstFast'     => 1,     # falls 1, beim ersten Mal nicht warten
                     '-debug'         => 0,
-                    '-prLog'         => undef,
+                    '-prLog'         => undef
                    );
 
     &::checkObjectParams(\%params, \@_, 'tinyWaitScheduler::new',
