@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2000-2013)
+#   Copyright (C) Heinz-Josef Claes (2000-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -19,6 +19,110 @@
 #
 
 
+######################################################################
+# usage of printLog
+# Prints lines formatted to STDOUT or a log file.
+#
+# my $prLog = $printLog('-file' => "fileName",  # optional, default is STDOUT
+#                       '-filedescriptor' => ...., # optional
+#                       '-kind' => [list of allowed messages'],
+#                       '-withTime' => 'yes',   # 'yes' or 'no'
+#                       '-withPID' => 'yes',    # 'yes' or 'no'
+#                       '-hostname' => '',
+#                       '-maxFileLen' => 1e6,
+#                       '-noOfOldFiles' => 5,
+#                       '-filter' => {},
+#                       '-closeFile' => 'no',
+#                       '-multiprint' => 'no',
+#                       '-saveLogs' => 'no',
+#                       '-compressWith' => undef,
+#                       '-tmpdir' => '/tmp'
+#                       );
+# $prLog->fork('pathTo_stbuLogPl');
+# my $fifo = $prLog->getFifoName();
+# $prLog->setStopAtNoMessages('-kind' => ..., '-stopAt' => ...,
+#                             '-message' => ...., '-exit' => ...);
+# my $enc = $prLog->encountered('-kind' => ....);
+# $prLog->setFileSpecs('-maxFilelen' => ...,, '-noOfOldFiles' => ....,
+#		       '-saveLogs' => 'no', '-compressWith' => undef
+# $prLog->printLog('-kind' => ..., '-str' => [...],
+#                  '-add' => ...., '-exit' => ....);
+# $prLog->pr(....);    # print list of lines directly
+# $prLog->DESTROY();
+#
+######################################################################
+# Options of printLog::new
+#
+# '-file'        file name where log messages have to be printed.
+#                default is undef, which means STDOUT
+# '-filedescriptor' write to file specified descriptor. '-file' must
+#                not be set if this option is used
+# '-kind'        default is ['I:INFO', 'W:WARNING', 'E:ERROR',
+#      	        'S:STATISTIC', 'D:DEBUG']
+#                example: $prLog->print('-kind' => 'I', ...)
+#                will print a message started with 'INFO'.
+#                If '-kind' is used with one word only (without :),
+#                you have to specify all of those letters as '-kind'
+#                parameter for method 'print()'
+# '-withTime'    'yes' or 'no', default is 'yes'
+#                additionally print the actual tome to the log file
+# '-withPID'     'yes' or 'no', default is 'yes'
+#                additionally print the PID to the log file
+# '-hostname'    additionally print the specified string (eg. hostname)
+#                to the log file
+# '-maxFilelen'  default: 1e6, 0 means unlimited file length
+#                size when to rotate the log file
+# '-noOfOldFiles' number of files to keep when rotating log files
+# '-filter'      Replace the output key by values of hashes specified
+#                eg: {'e' => 'E', '\s' => "\t"}
+#                will replace all instances of 'e' with 'E' and all
+#                instances white space with tabulators
+# '-closeFile'   open access to log file for each write and close
+#                directly afterwords. Default is 'no'
+# '-multiprint'  position to the end of the log file before each
+#                individual print statement. May be usefull if other
+#                processes write to the same log file. Default is 'no'
+#                better use method fork() if possible
+# '-saveLogs'    do not rotate log files. Store them with time stamp.
+#                Default is 'no' which means not to store (= rotate)
+# '-compressWith' specifiy compression algorithm for saving logs,
+#                may be eg. 'gzip -9', 'bzip2'. Default is undef which
+#                meancs not to compress
+# '-tmpdir'      default is '/tmp'. Used onyl if method 'fork()' is called
+#
+#######################################################################
+# Options of printLog::fork
+#
+# creates a named pipe and forks lib/stbuLog.pl
+#  which reads from that pipe
+# for each call of print (__reallyPrint) checks if 
+#  lib/stbuLog.pl was forked. If yes, writes to named
+#  pipe created
+# to be used if program is forked (not exec'ed!)
+# if fork exec, write to namend pipe in execed program directly
+# get the name of the fifo with getFifoName
+#
+# 1. parameter   path to directory where stbuLog.pl is located
+#
+#######################################################################
+# Options of printLog::getFifoName
+#
+# get name of the fifo file, see printLog::fork
+#
+#######################################################################
+# Options of printLog::setStopAtNoMessages
+#
+# process is exited after n messages of that type
+#
+# '-kind'        type of message to configure
+# '-stopAt'      stop after specified number of lines
+# '-message'     message to print, default is "too may errors, exiting"
+# '-exit'        exit status to use when exiting
+#
+#######################################################################
+# Options of printLog::encountered
+#
+
 
 use IO::Handle;
 use strict;
@@ -50,10 +154,12 @@ sub new
 		                              # vor bzw. nach jedem Schreiben
 		    '-multiprint'     => 'no',# pos an's Ende vor jedem print,
 		                              # mehrere Appl. print in ein log
+		                              # besser: methode fork()
 		    '-saveLogs'       => 'no',# nicht rundschreiben, wenn 'yes'
-		    '-compressWith'   => undef   # Komprimierungsprogr.,
+		    '-compressWith'   => undef,  # Komprimierungsprogr.,
 		                                 # z.B. 'gzip -9', 'bzip2'
 		                                 # nur zusammen mit '-saveLogs'
+		    '-tmpdir'         => '/tmp'  # used for forking (name pipe)
 		    );
 
     &::checkObjectParams(\%params, \@_, 'printLog::new', []);
@@ -110,7 +216,7 @@ sub new
 	$self->{'filehandle'} = *STDOUT;
     }
 
-    if (-f $params{'-file'})
+    if (defined $params{'-file'} and -f $params{'-file'})
     {
 	$self->{'filesize'} = (stat($params{'-file'}))[7];
     }
@@ -132,7 +238,7 @@ sub new
 #  lib/stbuLog.pl was forked. If yes, writes to named
 #  pipe created
 #
-# to be used if program is forked (not execed!)
+# to be used if program is forked (not exec'ed!)
 # if fork exec, write to namend pipe in execed program directly
 #  get the name of the fifo with getFifoName (see below)
 sub fork
@@ -141,8 +247,8 @@ sub fork
     my $pathTo_stbuLogPl = shift;
 
     return if defined $self->{'fifo'};
-
-    my $fifo = ::uniqFileName('/tmp/prLog-');
+    
+    my $fifo = ::uniqFileName($self->{'param'}{'-tmpdir'} . '/prLog-');
     POSIX::mkfifo($fifo, 0600) or
 	die "cannot mknod <$fifo> for printLog";
     $self->{'fifo'} = $fifo;
@@ -163,7 +269,7 @@ sub fork
 	}
 	else  # write round
 	{
-	    push @opts, ('--noOldFiles' => $self->{'param'}{'-noOfOldFiles'});
+	    push @opts, ('--noOfOldFiles' => $self->{'param'}{'-noOfOldFiles'});
 	}
     }
 
@@ -241,7 +347,7 @@ sub setFileSpecs
     my (%params) = ('-maxFilelen' => undef,
 		    '-noOfOldFiles' => undef,
 		    '-saveLogs' => 'no',
-		    '-compressWith'   => 'undef'
+		    '-compressWith'   => undef
 		    );
 
     &::checkObjectParams(\%params, \@_, 'printLog::print', []);
@@ -273,7 +379,7 @@ sub print
 			 ['-kind', '-str']);
 
     my $closeFile = $params{'-closeFile'};
-    if ($closeFile eq 'yes')
+    if (defined $closeFile and $closeFile eq 'yes')
     {
 	local *FILE;
 	open(FILE, ">>$params{'-file'}") or
@@ -294,8 +400,13 @@ sub print
     my $hostname = $self->{'param'}{'-hostname'};
     $hostname = "$hostname " if length($hostname);
 
-    my (@a, $a);
+    my (@b);
     foreach $a (@{$params{'-str'}})
+    {
+	push @b, split(/\n/, $a);
+    }
+    my (@a, $a);
+    foreach $a (@b)
     {
 	my $b;
 	foreach $b (keys %{$self->{filter}})
@@ -327,7 +438,7 @@ sub print
 
     exit $params{'-exit'} if ($params{'-exit'});   # Aufhren, falls gesetzt
 
-    if ($closeFile eq 'yes')
+    if (defined $closeFile and $closeFile eq 'yes')
     {
 	local *FILE = $self->{'filehandle'};
 	close(FILE);
@@ -402,7 +513,7 @@ sub __print         # interne Methode
 	    my $c = $self->{'param'}{'-compressWith'};
 	    if ($c)                # komprimieren
 	    {
-		my $pid = fork;
+		my $pid = CORE::fork;
 		if (defined($pid))     # fork erfolgreich
 		{
 		    goto Continue if $pid;     # im parent
