@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2012-2013)
+#   Copyright (C) Heinz-Josef Claes (2012-2020)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -104,14 +104,14 @@ stbuLog.pl - multiplex log files.
 
     maximal len of file written round (default = 1e6)
 
-=item B<-n>, B<--noOldFiles>
+=item B<-n>, B<--noOfOldFiles>
 
     number of old files to store
 
 =item B<-s>, B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOldFiles])
+    old (with [-noOfOldFiles])
 
 =item B<-c>, B<--compressWith>
 
@@ -121,14 +121,13 @@ stbuLog.pl - multiplex log files.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012 by Heinz-Josef Claes (see README)
+Copyright (c) 2012-2020 by Heinz-Josef Claes (see README)
 Published under the GNU General Public License or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
-$Help = "cannot find pod2text, see documentation for details\n"
-    unless $Help;
+#my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+my $Help = &::getPod2Text($0);
 
 $CheckPar = CheckParam->new('-allowLists' => 'no',
 			    '-list' => [
@@ -145,23 +144,19 @@ $CheckPar = CheckParam->new('-allowLists' => 'no',
 						    '-cl_option' => '-m',
 						    '-cl_alias' => '--maxFilelen',
 						    '-default' => 1e6),
-					Option->new('-name' => 'noOldFiles',
+					Option->new('-name' => 'noOfOldFiles',
 						    '-cl_option' => '-n',
-						    '-cl_alias' => '--noOldFiles',
-						    '-param' => 'yes',
-						    '-only_if' =>
-					   'not ( [saveLogs] or [compressWith])'),
+						    '-cl_alias' => '--noOfOldFiles',
+						    '-default' => '5',
+						    '-pattern' => '\A\d+\Z'),
 					Option->new('-name' => 'saveLogs',
 						    '-cl_option' => '-s',
 						    '-cl_alias' => '--saveLogs',
-						    '-only_if' =>
-						    '[out] and not [noOldFiles]'),
+						    '-only_if' => '[out]'),
 					Option->new('-name' => 'compressWith',
 						    '-cl_option' => '-c',
 						    '-cl_alias' => '--compressWith',
-						    '-param' => 'yes',
-						    '-only_if' =>
-						    '[out] and not [noOldFiles]')
+						    '-default' => 'bzip2')
 					]
 			    );
 
@@ -172,7 +167,7 @@ $CheckPar->check('-argv' => \@ARGV,
 $readFile = $CheckPar->getOptWithPar('readFile');
 $out = $CheckPar->getOptWithPar('out');
 $maxFilelen = $CheckPar->getOptWithPar('maxFilelen');
-$noOldFiles = $CheckPar->getOptWithPar('noOldFiles');
+$noOfOldFiles = $CheckPar->getOptWithPar('noOfOldFiles');
 $saveLogs = $CheckPar->getOptWithoutPar('saveLogs');
 $saveLogs = 'yes' if $saveLogs;
 $compressWith = $CheckPar->getOptWithPar('compressWith');
@@ -184,7 +179,7 @@ my (@fileout) = ();
 $prLog = printLog->new(@fileout,
 		       '-withTime' => $withTime,
 		       '-maxFilelen' => $maxFilelen,
-		       '-noOfOldFiles' => $noOldFiles,
+		       '-noOfOldFiles' => $noOfOldFiles,
 		       '-saveLogs' => $saveLogs,
 		       '-compressWith' => $compressWith,
 		       '-withPID' => 'no'
