@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2009-2013)
+#   Copyright (C) Heinz-Josef Claes (2009-2020)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -33,7 +33,7 @@ use POSIX ":sys_wait_h";
 
 
 
-my ($comprProg, $fileToRead, $fileToSave, $md5RetFile,
+my ($comprProg, $fileToRead, $fileToSave, $md5RetFile, $tmpdir,
     @comprProgFlags) = @ARGV;
 
 
@@ -43,7 +43,7 @@ unless (sysopen(IN, $fileToRead, O_RDONLY))
     exit 1;
 }
 
-my $prefix = "/tmp/stbu-md5Exec-";
+my $prefix = "$tmpdir/stbu-md5Exec-";
 my $suffix;
 do
 {
